@@ -19,7 +19,7 @@
 #![allow(dead_code)]
 #![allow(unused_variables)]
 
-use std::{cell::RefCell, rc::Rc};
+use std::{cell::RefCell, collections::HashMap, rc::Rc};
 
 use nautilus_common::{
     cache::Cache,
@@ -69,15 +69,27 @@ impl DataClient for BacktestDataClient {
     // -- COMMAND HANDLERS ---------------------------------------------------------------------------
 
     /// Parse command and call specific function
-    fn subscribe(&mut self, _data_type: &DataType) -> anyhow::Result<()> {
+    fn subscribe(
+        &mut self,
+        _data_type: &DataType,
+        _params: &Option<HashMap<String, String>>,
+    ) -> anyhow::Result<()> {
         Ok(())
     }
 
-    fn subscribe_instruments(&mut self, _venue: Option<&Venue>) -> anyhow::Result<()> {
+    fn subscribe_instruments(
+        &mut self,
+        _venue: Option<&Venue>,
+        _params: &Option<HashMap<String, String>>,
+    ) -> anyhow::Result<()> {
         Ok(())
     }
 
-    fn subscribe_instrument(&mut self, _instrument_id: &InstrumentId) -> anyhow::Result<()> {
+    fn subscribe_instrument(
+        &mut self,
+        _instrument_id: &InstrumentId,
+        _params: &Option<HashMap<String, String>>,
+    ) -> anyhow::Result<()> {
         Ok(())
     }
 
@@ -86,6 +98,7 @@ impl DataClient for BacktestDataClient {
         _instrument_id: &InstrumentId,
         _book_type: BookType,
         _depth: Option<usize>,
+        _params: &Option<HashMap<String, String>>,
     ) -> anyhow::Result<()> {
         Ok(())
     }
@@ -95,45 +108,79 @@ impl DataClient for BacktestDataClient {
         instrument_id: &InstrumentId,
         book_type: BookType,
         depth: Option<usize>,
+        params: &Option<HashMap<String, String>>,
     ) -> anyhow::Result<()> {
         Ok(())
     }
 
-    fn subscribe_quote_ticks(&mut self, instrument_id: &InstrumentId) -> anyhow::Result<()> {
+    fn subscribe_quote_ticks(
+        &mut self,
+        instrument_id: &InstrumentId,
+        params: &Option<HashMap<String, String>>,
+    ) -> anyhow::Result<()> {
         Ok(())
     }
 
-    fn subscribe_trade_ticks(&mut self, instrument_id: &InstrumentId) -> anyhow::Result<()> {
+    fn subscribe_trade_ticks(
+        &mut self,
+        instrument_id: &InstrumentId,
+        params: &Option<HashMap<String, String>>,
+    ) -> anyhow::Result<()> {
         Ok(())
     }
 
-    fn subscribe_bars(&mut self, bar_type: &BarType) -> anyhow::Result<()> {
+    fn subscribe_bars(
+        &mut self,
+        bar_type: &BarType,
+        params: &Option<HashMap<String, String>>,
+    ) -> anyhow::Result<()> {
         Ok(())
     }
 
-    fn subscribe_instrument_status(&mut self, instrument_id: &InstrumentId) -> anyhow::Result<()> {
+    fn subscribe_instrument_status(
+        &mut self,
+        instrument_id: &InstrumentId,
+        params: &Option<HashMap<String, String>>,
+    ) -> anyhow::Result<()> {
         Ok(())
     }
 
-    fn subscribe_instrument_close(&mut self, instrument_id: &InstrumentId) -> anyhow::Result<()> {
+    fn subscribe_instrument_close(
+        &mut self,
+        instrument_id: &InstrumentId,
+        params: &Option<HashMap<String, String>>,
+    ) -> anyhow::Result<()> {
         Ok(())
     }
 
-    fn unsubscribe(&mut self, data_type: &DataType) -> anyhow::Result<()> {
+    fn unsubscribe(
+        &mut self,
+        data_type: &DataType,
+        params: &Option<HashMap<String, String>>,
+    ) -> anyhow::Result<()> {
         Ok(())
     }
 
-    fn unsubscribe_instruments(&mut self, venue: Option<&Venue>) -> anyhow::Result<()> {
+    fn unsubscribe_instruments(
+        &mut self,
+        venue: Option<&Venue>,
+        params: &Option<HashMap<String, String>>,
+    ) -> anyhow::Result<()> {
         Ok(())
     }
 
-    fn unsubscribe_instrument(&mut self, instrument_id: &InstrumentId) -> anyhow::Result<()> {
+    fn unsubscribe_instrument(
+        &mut self,
+        instrument_id: &InstrumentId,
+        params: &Option<HashMap<String, String>>,
+    ) -> anyhow::Result<()> {
         Ok(())
     }
 
     fn unsubscribe_order_book_deltas(
         &mut self,
         instrument_id: &InstrumentId,
+        params: &Option<HashMap<String, String>>,
     ) -> anyhow::Result<()> {
         Ok(())
     }
@@ -141,30 +188,48 @@ impl DataClient for BacktestDataClient {
     fn unsubscribe_order_book_snapshots(
         &mut self,
         instrument_id: &InstrumentId,
+        params: &Option<HashMap<String, String>>,
     ) -> anyhow::Result<()> {
         Ok(())
     }
 
-    fn unsubscribe_quote_ticks(&mut self, instrument_id: &InstrumentId) -> anyhow::Result<()> {
+    fn unsubscribe_quote_ticks(
+        &mut self,
+        instrument_id: &InstrumentId,
+        params: &Option<HashMap<String, String>>,
+    ) -> anyhow::Result<()> {
         Ok(())
     }
 
-    fn unsubscribe_trade_ticks(&mut self, instrument_id: &InstrumentId) -> anyhow::Result<()> {
+    fn unsubscribe_trade_ticks(
+        &mut self,
+        instrument_id: &InstrumentId,
+        params: &Option<HashMap<String, String>>,
+    ) -> anyhow::Result<()> {
         Ok(())
     }
 
-    fn unsubscribe_bars(&mut self, bar_type: &BarType) -> anyhow::Result<()> {
+    fn unsubscribe_bars(
+        &mut self,
+        bar_type: &BarType,
+        params: &Option<HashMap<String, String>>,
+    ) -> anyhow::Result<()> {
         Ok(())
     }
 
     fn unsubscribe_instrument_status(
         &mut self,
         instrument_id: &InstrumentId,
+        params: &Option<HashMap<String, String>>,
     ) -> anyhow::Result<()> {
         Ok(())
     }
 
-    fn unsubscribe_instrument_close(&mut self, instrument_id: &InstrumentId) -> anyhow::Result<()> {
+    fn unsubscribe_instrument_close(
+        &mut self,
+        instrument_id: &InstrumentId,
+        params: &Option<HashMap<String, String>>,
+    ) -> anyhow::Result<()> {
         Ok(())
     }
 
@@ -180,6 +245,7 @@ impl DataClient for BacktestDataClient {
         venue: Venue,
         start: Option<UnixNanos>,
         end: Option<UnixNanos>,
+        params: &Option<HashMap<String, String>>,
     ) -> Vec<InstrumentAny> {
         todo!()
     }
@@ -190,6 +256,7 @@ impl DataClient for BacktestDataClient {
         instrument_id: InstrumentId,
         start: Option<UnixNanos>,
         end: Option<UnixNanos>,
+        params: &Option<HashMap<String, String>>,
     ) -> InstrumentAny {
         todo!()
     }
@@ -200,6 +267,7 @@ impl DataClient for BacktestDataClient {
         correlation_id: UUID4,
         instrument_id: InstrumentId,
         depth: Option<usize>,
+        params: &Option<HashMap<String, String>>,
     ) -> Payload {
         todo!()
     }
@@ -211,6 +279,7 @@ impl DataClient for BacktestDataClient {
         start: Option<UnixNanos>,
         end: Option<UnixNanos>,
         limit: Option<usize>,
+        params: &Option<HashMap<String, String>>,
     ) -> Vec<QuoteTick> {
         todo!()
     }
@@ -222,6 +291,7 @@ impl DataClient for BacktestDataClient {
         start: Option<UnixNanos>,
         end: Option<UnixNanos>,
         limit: Option<usize>,
+        params: &Option<HashMap<String, String>>,
     ) -> Vec<TradeTick> {
         todo!()
     }
@@ -233,6 +303,7 @@ impl DataClient for BacktestDataClient {
         start: Option<UnixNanos>,
         end: Option<UnixNanos>,
         limit: Option<usize>,
+        params: &Option<HashMap<String, String>>,
     ) -> Vec<Bar> {
         todo!()
     }
