@@ -169,6 +169,7 @@ mod tests {
     #[cfg(feature = "clock_v2")]
     use std::collections::BinaryHeap;
 
+    use std::num::NonZeroU64;
     #[rustfmt::skip]
     #[cfg(feature = "clock_v2")]
     use std::sync::Arc;
@@ -206,7 +207,7 @@ mod tests {
         // Create a new LiveTimer with no stop time
         let clock = get_atomic_clock_realtime();
         let start_time = clock.get_time_ns();
-        let interval_ns = 100 * NANOSECONDS_IN_MILLISECOND;
+        let interval_ns = NonZeroU64::new(100 * NANOSECONDS_IN_MILLISECOND).unwrap();
 
         #[cfg(not(feature = "clock_v2"))]
         let mut timer = LiveTimer::new("TEST_TIMER", interval_ns, start_time, None, callback);
@@ -242,7 +243,7 @@ mod tests {
         // Create a new LiveTimer with a stop time
         let clock = get_atomic_clock_realtime();
         let start_time = clock.get_time_ns();
-        let interval_ns = 100 * NANOSECONDS_IN_MILLISECOND;
+        let interval_ns = NonZeroU64::new(100 * NANOSECONDS_IN_MILLISECOND).unwrap();
         let stop_time = start_time + 500 * NANOSECONDS_IN_MILLISECOND;
 
         #[cfg(not(feature = "clock_v2"))]
@@ -292,7 +293,7 @@ mod tests {
         // Create a new LiveTimer with a stop time
         let clock = get_atomic_clock_realtime();
         let start_time = UnixNanos::default();
-        let interval_ns = 0;
+        let interval_ns = NonZeroU64::new(1).unwrap();
         let stop_time = clock.get_time_ns();
 
         #[cfg(not(feature = "clock_v2"))]
