@@ -22,6 +22,7 @@ use std::{
     str::FromStr,
 };
 
+use chrono::{DateTime, Utc};
 use serde::{Deserialize, Serialize};
 
 /// Represents a timestamp in nanoseconds since the UNIX epoch.
@@ -117,6 +118,12 @@ impl From<String> for UnixNanos {
     }
 }
 
+impl From<DateTime<Utc>> for UnixNanos {
+    fn from(value: DateTime<Utc>) -> Self {
+        Self::from(value.timestamp_nanos_opt().expect("Invalid timestamp") as u64)
+    }
+}
+
 impl FromStr for UnixNanos {
     type Err = std::num::ParseIntError;
 
