@@ -32,6 +32,7 @@ use nautilus_common::{
         switchboard::MessagingSwitchboard,
         MessageBus,
     },
+    testing::init_logger_for_testing,
 };
 use nautilus_core::{nanos::UnixNanos, uuid::UUID4};
 use nautilus_model::{
@@ -56,18 +57,6 @@ use crate::{
     mocks::MockDataClient,
 };
 
-// TODO: Used for development
-// fn init_logger(stdout_level: LevelFilter) {
-//     let mut config = LoggerConfig::default();
-//     config.stdout_level = stdout_level;
-//     init_logging(
-//         TraderId::default(),
-//         UUID4::new(),
-//         config,
-//         FileWriterConfig::default(),
-//     );
-// }
-
 #[fixture]
 fn trader_id() -> TraderId {
     TraderId::default()
@@ -170,6 +159,7 @@ fn test_execute_subscribe_custom_data(
         Action::Subscribe,
         UUID4::new(),
         UnixNanos::default(),
+        None,
     );
     msgbus.borrow().send(&endpoint, &cmd as &dyn Any);
     data_engine.borrow_mut().run();
@@ -186,6 +176,7 @@ fn test_execute_subscribe_custom_data(
         Action::Unsubscribe,
         UUID4::new(),
         UnixNanos::default(),
+        None,
     );
     msgbus.borrow().send(&endpoint, &cmd as &dyn Any);
     data_engine.borrow_mut().run();
@@ -228,6 +219,7 @@ fn test_execute_subscribe_order_book_deltas(
         Action::Subscribe,
         UUID4::new(),
         UnixNanos::default(),
+        None,
     );
     msgbus.borrow().send(&endpoint, &cmd as &dyn Any);
     data_engine.borrow_mut().run();
@@ -244,6 +236,7 @@ fn test_execute_subscribe_order_book_deltas(
         Action::Unsubscribe,
         UUID4::new(),
         UnixNanos::default(),
+        None,
     );
     msgbus.borrow().send(&endpoint, &cmd as &dyn Any);
     data_engine.borrow_mut().run();
@@ -286,6 +279,7 @@ fn test_execute_subscribe_order_book_snapshots(
         Action::Subscribe,
         UUID4::new(),
         UnixNanos::default(),
+        None,
     );
     msgbus.borrow().send(&endpoint, &cmd as &dyn Any);
     data_engine.borrow_mut().run();
@@ -302,6 +296,7 @@ fn test_execute_subscribe_order_book_snapshots(
         Action::Unsubscribe,
         UUID4::new(),
         UnixNanos::default(),
+        None,
     );
     msgbus.borrow().send(&endpoint, &cmd as &dyn Any);
     data_engine.borrow_mut().run();
@@ -342,6 +337,7 @@ fn test_execute_subscribe_instrument(
         Action::Subscribe,
         UUID4::new(),
         UnixNanos::default(),
+        None,
     );
     msgbus.borrow().send(&endpoint, &cmd as &dyn Any);
     data_engine.borrow_mut().run();
@@ -358,6 +354,7 @@ fn test_execute_subscribe_instrument(
         Action::Unsubscribe,
         UUID4::new(),
         UnixNanos::default(),
+        None,
     );
     msgbus.borrow().send(&endpoint, &cmd as &dyn Any);
     data_engine.borrow_mut().run();
@@ -398,6 +395,7 @@ fn test_execute_subscribe_quote_ticks(
         Action::Subscribe,
         UUID4::new(),
         UnixNanos::default(),
+        None,
     );
     msgbus.borrow().send(&endpoint, &cmd as &dyn Any);
     data_engine.borrow_mut().run();
@@ -414,6 +412,7 @@ fn test_execute_subscribe_quote_ticks(
         Action::Unsubscribe,
         UUID4::new(),
         UnixNanos::default(),
+        None,
     );
     msgbus.borrow().send(&endpoint, &cmd as &dyn Any);
     data_engine.borrow_mut().run();
@@ -454,6 +453,7 @@ fn test_execute_subscribe_trade_ticks(
         Action::Subscribe,
         UUID4::new(),
         UnixNanos::default(),
+        None,
     );
     msgbus.borrow().send(&endpoint, &cmd as &dyn Any);
     data_engine.borrow_mut().run();
@@ -470,6 +470,7 @@ fn test_execute_subscribe_trade_ticks(
         Action::Unsubscribe,
         UUID4::new(),
         UnixNanos::default(),
+        None,
     );
     msgbus.borrow().send(&endpoint, &cmd as &dyn Any);
     data_engine.borrow_mut().run();
@@ -482,14 +483,13 @@ fn test_execute_subscribe_trade_ticks(
 
 #[rstest]
 fn test_execute_subscribe_bars(
+    audusd_sim: CurrencyPair,
     msgbus: Rc<RefCell<MessageBus>>,
     switchboard: MessagingSwitchboard,
     data_engine: Rc<RefCell<DataEngine>>,
     data_client: DataClientAdapter,
 ) {
-    let client_id = data_client.client_id;
-    let venue = data_client.venue;
-    data_engine.borrow_mut().register_client(data_client, None);
+    init_logger_for_testing(None); // TODO: Remove once initial development completed
 
     let endpoint = switchboard.data_engine_execute;
     let handler = ShareableMessageHandler(Rc::new(SubscriptionCommandHandler {
@@ -498,7 +498,14 @@ fn test_execute_subscribe_bars(
     }));
     msgbus.borrow_mut().register(endpoint, handler);
 
-    let bar_type = BarType::from("AUDUSD.SIM-1-MINUTE-LAST-INTERNAL");
+    let audusd_sim = InstrumentAny::CurrencyPair(audusd_sim);
+    data_engine.borrow_mut().process(&audusd_sim as &dyn Any);
+
+    let client_id = data_client.client_id;
+    let venue = data_client.venue;
+    data_engine.borrow_mut().register_client(data_client, None);
+
+    let bar_type = BarType::from("AUD/USD.SIM-1-MINUTE-LAST-INTERNAL");
     let metadata = indexmap! {
         "bar_type".to_string() => bar_type.to_string(),
     };
@@ -510,6 +517,7 @@ fn test_execute_subscribe_bars(
         Action::Subscribe,
         UUID4::new(),
         UnixNanos::default(),
+        None,
     );
     msgbus.borrow().send(&endpoint, &cmd as &dyn Any);
     data_engine.borrow_mut().run();
@@ -523,10 +531,12 @@ fn test_execute_subscribe_bars(
         Action::Unsubscribe,
         UUID4::new(),
         UnixNanos::default(),
+        None,
     );
     msgbus.borrow().send(&endpoint, &cmd as &dyn Any);
     data_engine.borrow_mut().run();
 
+    assert_eq!(audusd_sim.id(), bar_type.instrument_id());
     assert!(!data_engine.borrow().subscribed_bars().contains(&bar_type));
 }
 
@@ -561,6 +571,7 @@ fn test_process_instrument(
         Action::Subscribe,
         UUID4::new(),
         UnixNanos::default(),
+        None,
     );
     msgbus.borrow().send(&endpoint, &cmd as &dyn Any);
 
@@ -609,6 +620,7 @@ fn test_process_order_book_delta(
         Action::Subscribe,
         UUID4::new(),
         UnixNanos::default(),
+        None,
     );
 
     let endpoint = switchboard.data_engine_execute;
@@ -660,6 +672,7 @@ fn test_process_order_book_deltas(
         Action::Subscribe,
         UUID4::new(),
         UnixNanos::default(),
+        None,
     );
 
     let endpoint = switchboard.data_engine_execute;
@@ -713,6 +726,7 @@ fn test_process_order_book_depth10(
         Action::Subscribe,
         UUID4::new(),
         UnixNanos::default(),
+        None,
     );
 
     let endpoint = switchboard.data_engine_execute;
@@ -763,6 +777,7 @@ fn test_process_quote_tick(
         Action::Subscribe,
         UUID4::new(),
         UnixNanos::default(),
+        None,
     );
 
     let endpoint = switchboard.data_engine_execute;
@@ -814,6 +829,7 @@ fn test_process_trade_tick(
         Action::Subscribe,
         UUID4::new(),
         UnixNanos::default(),
+        None,
     );
 
     let endpoint = switchboard.data_engine_execute;
@@ -865,6 +881,7 @@ fn test_process_bar(
         Action::Subscribe,
         UUID4::new(),
         UnixNanos::default(),
+        None,
     );
 
     let endpoint = switchboard.data_engine_execute;
