@@ -31,3 +31,7 @@ pub mod client;
 pub mod engine;
 pub mod matching_core;
 pub mod messages;
+pub mod reports;
+
+#[cfg(feature = "python")]
+pub mod python;
