@@ -19,11 +19,19 @@ mod serial_tests {
     use std::{collections::HashSet, time::Duration};
 
     use bytes::Bytes;
-    use nautilus_common::{cache::database::CacheDatabaseAdapter, testing::wait_until};
-    use nautilus_infrastructure::sql::cache_database::get_pg_cache_database;
+    use indexmap::indexmap;
+    use nautilus_common::{
+        cache::database::CacheDatabaseAdapter, custom::CustomData, signal::Signal,
+        testing::wait_until,
+    };
+    use nautilus_core::nanos::UnixNanos;
+    use nautilus_infrastructure::sql::cache::get_pg_cache_database;
     use nautilus_model::{
         accounts::{any::AccountAny, cash::CashAccount},
-        data::stubs::{quote_tick_ethusdt_binance, stub_bar, stub_trade_tick_ethusdt_buyer},
+        data::{
+            stubs::{quote_ethusdt_binance, stub_bar, stub_trade_ethusdt_buyer},
+            DataType,
+        },
         enums::{CurrencyType, OrderSide, OrderStatus, OrderType},
         events::account::stubs::cash_account_state_million_usd,
         identifiers::{
@@ -33,8 +41,8 @@ mod serial_tests {
         instruments::{
             any::InstrumentAny,
             stubs::{
-                audusd_sim, crypto_future_btcusdt, crypto_perpetual_ethusdt, currency_pair_ethusdt,
-                equity_aapl, futures_contract_es, options_contract_appl,
+                audusd_sim, binary_option, crypto_future_btcusdt, crypto_perpetual_ethusdt,
+                currency_pair_ethusdt, equity_aapl, futures_contract_es, options_contract_appl,
             },
             Instrument,
         },
@@ -54,6 +62,7 @@ mod serial_tests {
     #[tokio::test(flavor = "multi_thread")]
     async fn test_add_general_object_adds_to_cache() {
         let mut pg_cache = get_pg_cache_database().await.unwrap();
+
         let test_id_value = Bytes::from("test_value");
         pg_cache
             .add(String::from("test_id"), test_id_value.clone())
@@ -72,23 +81,31 @@ mod serial_tests {
             vec![String::from("test_id")]
         );
         assert_eq!(result.get("test_id").unwrap().to_owned(), test_id_value);
+
+        pg_cache.flush().unwrap();
+        pg_cache.close().unwrap();
     }
 
     #[tokio::test(flavor = "multi_thread")]
     async fn test_add_currency_and_instruments() {
-        // 1. first define and add currencies as they are contain foreign keys for instruments
         let mut pg_cache = get_pg_cache_database().await.unwrap();
+
         // Define currencies
         let btc = Currency::new("BTC", 8, 0, "BTC", CurrencyType::Crypto);
         let eth = Currency::new("ETH", 2, 0, "ETH", CurrencyType::Crypto);
+        let gbp = Currency::new("GBP", 2, 0, "GBP", CurrencyType::Fiat);
         let usd = Currency::new("USD", 2, 0, "USD", CurrencyType::Fiat);
+        let usdc = Currency::new("USDC", 8, 0, "USDC", CurrencyType::Crypto);
         let usdt = Currency::new("USDT", 2, 0, "USDT", CurrencyType::Crypto);
         // Insert all the currencies
         pg_cache.add_currency(&btc).unwrap();
         pg_cache.add_currency(&eth).unwrap();
+        pg_cache.add_currency(&gbp).unwrap();
         pg_cache.add_currency(&usd).unwrap();
+        pg_cache.add_currency(&usdc).unwrap();
         pg_cache.add_currency(&usdt).unwrap();
         // Define all the instruments
+        let binary_option = binary_option();
         let crypto_future =
             crypto_future_btcusdt(2, 6, Price::from("0.01"), Quantity::from("0.000001"));
         let crypto_perpetual = crypto_perpetual_ethusdt();
@@ -97,6 +114,9 @@ mod serial_tests {
         let futures_contract = futures_contract_es(None, None);
         let options_contract = options_contract_appl();
         // Insert all the instruments
+        pg_cache
+            .add_instrument(&InstrumentAny::BinaryOption(binary_option))
+            .unwrap();
         pg_cache
             .add_instrument(&InstrumentAny::CryptoFuture(crypto_future))
             .unwrap();
@@ -120,13 +140,13 @@ mod serial_tests {
             || {
                 let currencies = pg_cache.load_currencies().unwrap();
                 let instruments = pg_cache.load_instruments().unwrap();
-                currencies.len() >= 4 && instruments.len() >= 6
+                currencies.len() >= 6 && instruments.len() >= 7
             },
             Duration::from_secs(2),
         );
         // Check that currency list is correct
         let currencies = pg_cache.load_currencies().unwrap();
-        assert_eq!(currencies.len(), 4);
+        assert_eq!(currencies.len(), 6);
         assert_eq!(
             currencies
                 .into_values()
@@ -135,7 +155,9 @@ mod serial_tests {
             vec![
                 String::from("BTC"),
                 String::from("ETH"),
+                String::from("GBP"),
                 String::from("USD"),
+                String::from("USDC"),
                 String::from("USDT")
             ]
             .into_iter()
@@ -150,6 +172,21 @@ mod serial_tests {
             pg_cache.load_currency(&Ustr::from("ETH")).unwrap().unwrap(),
             eth
         );
+        assert_eq!(
+            pg_cache.load_currency(&Ustr::from("GBP")).unwrap().unwrap(),
+            gbp
+        );
+        assert_eq!(
+            pg_cache.load_currency(&Ustr::from("USD")).unwrap().unwrap(),
+            usd
+        );
+        assert_eq!(
+            pg_cache
+                .load_currency(&Ustr::from("USDC"))
+                .unwrap()
+                .unwrap(),
+            usdc
+        );
         assert_eq!(
             pg_cache
                 .load_currency(&Ustr::from("USDT"))
@@ -158,6 +195,13 @@ mod serial_tests {
             usdt
         );
         // Check individual instruments
+        assert_eq!(
+            pg_cache
+                .load_instrument(&binary_option.id())
+                .unwrap()
+                .unwrap(),
+            InstrumentAny::BinaryOption(binary_option)
+        );
         assert_eq!(
             pg_cache
                 .load_instrument(&crypto_future.id())
@@ -199,10 +243,11 @@ mod serial_tests {
         );
         // Check that instrument list is correct
         let instruments = pg_cache.load_instruments().unwrap();
-        assert_eq!(instruments.len(), 6);
+        assert_eq!(instruments.len(), 7);
         assert_eq!(
             instruments.into_keys().collect::<HashSet<InstrumentId>>(),
             vec![
+                binary_option.id(),
                 crypto_future.id(),
                 crypto_perpetual.id(),
                 currency_pair.id(),
@@ -213,14 +258,18 @@ mod serial_tests {
             .into_iter()
             .collect::<HashSet<InstrumentId>>()
         );
+
+        pg_cache.flush().unwrap();
+        pg_cache.close().unwrap();
     }
 
     #[tokio::test(flavor = "multi_thread")]
     async fn test_postgres_cache_database_add_order_and_load_indexes() {
+        let mut pg_cache = get_pg_cache_database().await.unwrap();
+
         let client_order_id_1 = ClientOrderId::new("O-19700101-000000-001-001-1");
         let client_order_id_2 = ClientOrderId::new("O-19700101-000000-001-001-2");
         let instrument = currency_pair_ethusdt();
-        let mut pg_cache = get_pg_cache_database().await.unwrap();
 
         let market_order = OrderTestBuilder::new(OrderType::Market)
             .instrument_id(instrument.id())
@@ -287,14 +336,18 @@ mod serial_tests {
                 .collect::<HashSet<ClientId>>(),
             vec![client_id].into_iter().collect::<HashSet<ClientId>>()
         );
+
+        pg_cache.flush().unwrap();
+        pg_cache.close().unwrap();
     }
 
     #[tokio::test(flavor = "multi_thread")]
     async fn test_update_order_for_open_order() {
+        let mut pg_cache = get_pg_cache_database().await.unwrap();
+
         let client_order_id_1 = ClientOrderId::new("O-19700101-000000-001-002-1");
         let instrument = InstrumentAny::CurrencyPair(currency_pair_ethusdt());
         let account = account_id();
-        let mut pg_cache = get_pg_cache_database().await.unwrap();
         // add foreign key dependencies: instrument and currencies
         pg_cache
             .add_currency(&instrument.base_currency().unwrap())
@@ -311,12 +364,12 @@ mod serial_tests {
         pg_cache.add_order(&market_order, None).unwrap();
         let submitted = TestOrderEventStubs::order_submitted(&market_order, account);
         market_order.apply(submitted).unwrap();
-        pg_cache.update_order(&market_order).unwrap();
+        pg_cache.update_order(market_order.last_event()).unwrap();
 
         let accepted =
             TestOrderEventStubs::order_accepted(&market_order, account, VenueOrderId::new("001"));
         market_order.apply(accepted).unwrap();
-        pg_cache.update_order(&market_order).unwrap();
+        pg_cache.update_order(market_order.last_event()).unwrap();
 
         let filled = TestOrderEventStubs::order_filled(
             &market_order,
@@ -331,7 +384,7 @@ mod serial_tests {
             Some(AccountId::new("SIM-001")),
         );
         market_order.apply(filled).unwrap();
-        pg_cache.update_order(&market_order).unwrap();
+        pg_cache.update_order(market_order.last_event()).unwrap();
         wait_until(
             || {
                 let result = pg_cache
@@ -346,11 +399,15 @@ mod serial_tests {
             .load_order(&market_order.client_order_id())
             .unwrap();
         entirely_equal(market_order_result.unwrap(), market_order);
+
+        pg_cache.flush().unwrap();
+        pg_cache.close().unwrap();
     }
 
     #[tokio::test(flavor = "multi_thread")]
     async fn test_add_and_update_account() {
-        let mut pg_cache = get_pg_cache_database().await.unwrap();
+        let pg_cache = get_pg_cache_database().await.unwrap();
+
         let mut account = AccountAny::Cash(CashAccount::new(
             cash_account_state_million_usd("1000000 USD", "0 USD", "1000000 USD"),
             false,
@@ -395,7 +452,7 @@ mod serial_tests {
         pg_cache.add_currency(&instrument.quote_currency()).unwrap();
         pg_cache.add_instrument(&instrument).unwrap();
         // add trade tick
-        let trade_tick = stub_trade_tick_ethusdt_buyer();
+        let trade_tick = stub_trade_ethusdt_buyer();
         pg_cache.add_trade(&trade_tick).unwrap();
         wait_until(
             || {
@@ -410,11 +467,15 @@ mod serial_tests {
         let trades = pg_cache.load_trades(&instrument.id()).unwrap();
         assert_eq!(trades.len(), 1);
         assert_eq!(trades[0], trade_tick);
+
+        pg_cache.flush().unwrap();
+        pg_cache.close().unwrap();
     }
 
     #[tokio::test(flavor = "multi_thread")]
     async fn test_postgres_cache_database_add_quote_tick() {
         let mut pg_cache = get_pg_cache_database().await.unwrap();
+
         // add target instrument and currencies
         let instrument = InstrumentAny::CryptoPerpetual(crypto_perpetual_ethusdt());
         pg_cache
@@ -423,7 +484,7 @@ mod serial_tests {
         pg_cache.add_currency(&instrument.quote_currency()).unwrap();
         pg_cache.add_instrument(&instrument).unwrap();
         // add quote tick
-        let quote_tick = quote_tick_ethusdt_binance();
+        let quote_tick = quote_ethusdt_binance();
         pg_cache.add_quote(&quote_tick).unwrap();
         wait_until(
             || {
@@ -438,11 +499,15 @@ mod serial_tests {
         let quotes = pg_cache.load_quotes(&instrument.id()).unwrap();
         assert_eq!(quotes.len(), 1);
         assert_eq!(quotes[0], quote_tick);
+
+        pg_cache.flush().unwrap();
+        pg_cache.close().unwrap();
     }
 
     #[tokio::test(flavor = "multi_thread")]
     async fn test_postgres_cache_database_add_bar() {
         let mut pg_cache = get_pg_cache_database().await.unwrap();
+
         // add target instrument and currencies
         let instrument = InstrumentAny::CurrencyPair(audusd_sim());
         pg_cache
@@ -466,11 +531,15 @@ mod serial_tests {
         let bars = pg_cache.load_bars(&instrument.id()).unwrap();
         assert_eq!(bars.len(), 1);
         assert_eq!(bars[0], bar);
+
+        pg_cache.flush().unwrap();
+        pg_cache.close().unwrap();
     }
 
     #[tokio::test(flavor = "multi_thread")]
     async fn test_truncate() {
         let mut pg_cache = get_pg_cache_database().await.unwrap();
+
         // add items in currency and instrument table
         let instrument = InstrumentAny::CurrencyPair(audusd_sim());
         pg_cache
@@ -494,5 +563,65 @@ mod serial_tests {
         assert_eq!(currencies.len(), 0);
         let instruments = pg_cache.load_instruments().unwrap();
         assert_eq!(instruments.len(), 0);
+
+        pg_cache.flush().unwrap();
+        pg_cache.close().unwrap();
+    }
+
+    #[tokio::test(flavor = "multi_thread")]
+    async fn test_postgres_cache_database_add_signal() {
+        let mut pg_cache = get_pg_cache_database().await.unwrap();
+
+        // Add signal
+        let name = Ustr::from("SignalExample");
+        let value = "0.0".to_string();
+        let signal = Signal::new(name, value, UnixNanos::from(1), UnixNanos::from(2));
+        pg_cache.add_signal(&signal).unwrap();
+
+        wait_until(
+            || pg_cache.load_signals(name.as_str()).unwrap().len() == 1,
+            Duration::from_secs(2),
+        );
+
+        let signals = pg_cache.load_signals(name.as_str()).unwrap();
+        assert_eq!(signals.len(), 1);
+        assert_eq!(signals[0], signal);
+
+        pg_cache.flush().unwrap();
+        pg_cache.close().unwrap();
+    }
+
+    #[tokio::test(flavor = "multi_thread")]
+    async fn test_postgres_cache_database_add_custom_data() {
+        let mut pg_cache = get_pg_cache_database().await.unwrap();
+
+        // Add custom data
+        let metadata =
+            indexmap! {"a".to_string() => "1".to_string(), "b".to_string() => "2".to_string()};
+        let data_type = DataType::new("TestData", Some(metadata));
+        let json_stub_value = r#"{"a":"1","b":"2"}"#;
+        let json_value: serde_json::Value = serde_json::from_str(json_stub_value).unwrap();
+        let serialized_bytes = serde_json::to_vec(&json_value).unwrap();
+
+        let data = CustomData::new(
+            data_type.clone(),
+            Bytes::from(serialized_bytes),
+            UnixNanos::default(),
+            UnixNanos::default(),
+        );
+
+        pg_cache.add_custom_data(&data).unwrap();
+
+        wait_until(
+            || pg_cache.load_custom_data(&data_type).unwrap().len() == 1,
+            Duration::from_secs(2),
+        );
+
+        let datas = pg_cache.load_custom_data(&data_type).unwrap();
+        assert_eq!(datas.len(), 1);
+        assert_eq!(datas[0], data);
+
+        pg_cache.flush().unwrap();
+        pg_cache.close().unwrap();
     }
 }
