@@ -15,7 +15,7 @@
 
 use std::ffi::c_char;
 
-use nautilus_core::ffi::string::cstr_to_str;
+use nautilus_core::ffi::string::cstr_as_str;
 
 use crate::identifiers::venue_order_id::VenueOrderId;
 
@@ -26,7 +26,7 @@ use crate::identifiers::venue_order_id::VenueOrderId;
 /// - Assumes `ptr` is a valid C string pointer.
 #[no_mangle]
 pub unsafe extern "C" fn venue_order_id_new(ptr: *const c_char) -> VenueOrderId {
-    VenueOrderId::from(cstr_to_str(ptr))
+    VenueOrderId::from(cstr_as_str(ptr))
 }
 
 #[no_mangle]
