@@ -40,29 +40,53 @@ use crate::{
 )]
 #[cfg_attr(feature = "trivial_copy", derive(Copy))]
 pub struct CryptoPerpetual {
+    /// The instrument ID for the instrument.
     pub id: InstrumentId,
+    /// The raw/local/native symbol for the instrument, assigned by the venue.
     pub raw_symbol: Symbol,
+    /// The base currency.
     pub base_currency: Currency,
+    /// The quote currency.
     pub quote_currency: Currency,
+    /// The settlement currency.
     pub settlement_currency: Currency,
+    /// If the instrument costing is inverse (quantity expressed in quote currency units).
     pub is_inverse: bool,
+    /// The price decimal precision.
     pub price_precision: u8,
+    /// The trading size decimal precision.
     pub size_precision: u8,
+    /// The minimum price increment (tick size).
     pub price_increment: Price,
+    /// The minimum size increment.
     pub size_increment: Quantity,
-    pub maker_fee: Decimal,
-    pub taker_fee: Decimal,
-    pub margin_init: Decimal,
-    pub margin_maint: Decimal,
+    /// The contract multiplier.
     pub multiplier: Quantity,
+    /// The rounded lot unit size (standard/board).
     pub lot_size: Quantity,
+    /// The initial (order) margin requirement in percentage of order value.
+    pub margin_init: Decimal,
+    /// The maintenance (position) margin in percentage of position value.
+    pub margin_maint: Decimal,
+    /// The fee rate for liquidity makers as a percentage of order value.
+    pub maker_fee: Decimal,
+    /// The fee rate for liquidity takers as a percentage of order value.
+    pub taker_fee: Decimal,
+    /// The maximum allowable order quantity.
     pub max_quantity: Option<Quantity>,
+    /// The minimum allowable order quantity.
     pub min_quantity: Option<Quantity>,
+    /// The maximum allowable order notional value.
     pub max_notional: Option<Money>,
+    /// The minimum allowable order notional value.
     pub min_notional: Option<Money>,
+    /// The maximum allowable quoted price.
     pub max_price: Option<Price>,
+    /// The minimum allowable quoted price.
     pub min_price: Option<Price>,
+    /// UNIX timestamp (nanoseconds) when the data event occurred.
     pub ts_event: UnixNanos,
+    /// UNIX timestamp (nanoseconds) when the data object was initialized.
     pub ts_init: UnixNanos,
 }
 
@@ -84,10 +108,6 @@ impl CryptoPerpetual {
         size_precision: u8,
         price_increment: Price,
         size_increment: Quantity,
-        maker_fee: Decimal,
-        taker_fee: Decimal,
-        margin_init: Decimal,
-        margin_maint: Decimal,
         multiplier: Option<Quantity>,
         lot_size: Option<Quantity>,
         max_quantity: Option<Quantity>,
@@ -96,6 +116,10 @@ impl CryptoPerpetual {
         min_notional: Option<Money>,
         max_price: Option<Price>,
         min_price: Option<Price>,
+        margin_init: Option<Decimal>,
+        margin_maint: Option<Decimal>,
+        maker_fee: Option<Decimal>,
+        taker_fee: Option<Decimal>,
         ts_event: UnixNanos,
         ts_init: UnixNanos,
     ) -> anyhow::Result<Self> {
@@ -125,12 +149,12 @@ impl CryptoPerpetual {
             size_precision,
             price_increment,
             size_increment,
-            maker_fee,
-            taker_fee,
-            margin_init,
-            margin_maint,
             multiplier: multiplier.unwrap_or(Quantity::from(1)),
             lot_size: lot_size.unwrap_or(Quantity::from(1)),
+            margin_init: margin_init.unwrap_or_default(),
+            margin_maint: margin_maint.unwrap_or_default(),
+            maker_fee: maker_fee.unwrap_or_default(),
+            taker_fee: taker_fee.unwrap_or_default(),
             max_quantity,
             min_quantity,
             max_notional,
@@ -155,10 +179,6 @@ impl CryptoPerpetual {
         size_precision: u8,
         price_increment: Price,
         size_increment: Quantity,
-        maker_fee: Decimal,
-        taker_fee: Decimal,
-        margin_init: Decimal,
-        margin_maint: Decimal,
         multiplier: Option<Quantity>,
         lot_size: Option<Quantity>,
         max_quantity: Option<Quantity>,
@@ -167,6 +187,10 @@ impl CryptoPerpetual {
         min_notional: Option<Money>,
         max_price: Option<Price>,
         min_price: Option<Price>,
+        margin_init: Option<Decimal>,
+        margin_maint: Option<Decimal>,
+        maker_fee: Option<Decimal>,
+        taker_fee: Option<Decimal>,
         ts_event: UnixNanos,
         ts_init: UnixNanos,
     ) -> Self {
@@ -181,10 +205,6 @@ impl CryptoPerpetual {
             size_precision,
             price_increment,
             size_increment,
-            maker_fee,
-            taker_fee,
-            margin_init,
-            margin_maint,
             multiplier,
             lot_size,
             max_quantity,
@@ -193,6 +213,10 @@ impl CryptoPerpetual {
             min_notional,
             max_price,
             min_price,
+            margin_init,
+            margin_maint,
+            maker_fee,
+            taker_fee,
             ts_event,
             ts_init,
         )
