@@ -17,7 +17,8 @@ use std::hash::{Hash, Hasher};
 
 use nautilus_core::{
     correctness::{
-        check_equal_u8, check_positive_i64, check_valid_string, check_valid_string_optional, FAILED,
+        check_equal_u8, check_positive_i64, check_positive_u64, check_valid_string,
+        check_valid_string_optional, FAILED,
     },
     nanos::UnixNanos,
 };
@@ -41,30 +42,57 @@ use crate::{
 )]
 #[cfg_attr(feature = "trivial_copy", derive(Copy))]
 pub struct OptionsContract {
+    /// The instrument ID.
     pub id: InstrumentId,
+    /// The raw/local/native symbol for the instrument, assigned by the venue.
     pub raw_symbol: Symbol,
+    /// The options contract asset class.
     pub asset_class: AssetClass,
     /// The exchange ISO 10383 Market Identifier Code (MIC) where the instrument trades.
     pub exchange: Option<Ustr>,
+    /// The underlying asset.
     pub underlying: Ustr,
+    /// The kind of option (PUT | CALL).
     pub option_kind: OptionKind,
+    /// The option strike price.
     pub strike_price: Price,
+    /// UNIX timestamp (nanoseconds) for contract activation.
     pub activation_ns: UnixNanos,
+    /// UNIX timestamp (nanoseconds) for contract expiration.
     pub expiration_ns: UnixNanos,
+    /// The options contract currency.
     pub currency: Currency,
+    /// The price decimal precision.
     pub price_precision: u8,
+    /// The minimum price increment (tick size).
     pub price_increment: Price,
+    /// The minimum size increment.
     pub size_increment: Quantity,
+    /// The trading size decimal precision.
     pub size_precision: u8,
+    /// The option multiplier.
     pub multiplier: Quantity,
+    /// The rounded lot unit size (standard/board).
     pub lot_size: Quantity,
+    /// The initial (order) margin requirement in percentage of order value.
     pub margin_init: Decimal,
+    /// The maintenance (position) margin in percentage of position value.
     pub margin_maint: Decimal,
+    /// The fee rate for liquidity makers as a percentage of order value.
+    pub maker_fee: Decimal,
+    /// The fee rate for liquidity takers as a percentage of order value.
+    pub taker_fee: Decimal,
+    /// The maximum allowable order quantity.
     pub max_quantity: Option<Quantity>,
+    /// The minimum allowable order quantity.
     pub min_quantity: Option<Quantity>,
+    /// The maximum allowable quoted price.
     pub max_price: Option<Price>,
+    /// The minimum allowable quoted price.
     pub min_price: Option<Price>,
+    /// UNIX timestamp (nanoseconds) when the data event occurred.
     pub ts_event: UnixNanos,
+    /// UNIX timestamp (nanoseconds) when the data object was initialized.
     pub ts_init: UnixNanos,
 }
 
@@ -96,6 +124,8 @@ impl OptionsContract {
         min_price: Option<Price>,
         margin_init: Option<Decimal>,
         margin_maint: Option<Decimal>,
+        maker_fee: Option<Decimal>,
+        taker_fee: Option<Decimal>,
         ts_event: UnixNanos,
         ts_init: UnixNanos,
     ) -> anyhow::Result<Self> {
@@ -108,6 +138,8 @@ impl OptionsContract {
             stringify!(price_increment.precision),
         )?;
         check_positive_i64(price_increment.raw, stringify!(price_increment.raw))?;
+        check_positive_u64(multiplier.raw, stringify!(multiplier.raw))?;
+        check_positive_u64(lot_size.raw, stringify!(lot_size.raw))?;
 
         Ok(Self {
             id,
@@ -126,12 +158,14 @@ impl OptionsContract {
             size_increment: Quantity::from("1"),
             multiplier,
             lot_size,
+            margin_init: margin_init.unwrap_or_default(),
+            margin_maint: margin_maint.unwrap_or_default(),
+            maker_fee: maker_fee.unwrap_or_default(),
+            taker_fee: taker_fee.unwrap_or_default(),
             max_quantity,
             min_quantity: Some(min_quantity.unwrap_or(1.into())),
             max_price,
             min_price,
-            margin_init: margin_init.unwrap_or(0.into()),
-            margin_maint: margin_maint.unwrap_or(0.into()),
             ts_event,
             ts_init,
         })
@@ -160,6 +194,8 @@ impl OptionsContract {
         min_price: Option<Price>,
         margin_init: Option<Decimal>,
         margin_maint: Option<Decimal>,
+        maker_fee: Option<Decimal>,
+        taker_fee: Option<Decimal>,
         ts_event: UnixNanos,
         ts_init: UnixNanos,
     ) -> Self {
@@ -184,6 +220,8 @@ impl OptionsContract {
             min_price,
             margin_init,
             margin_maint,
+            maker_fee,
+            taker_fee,
             ts_event,
             ts_init,
         )
