@@ -13,6 +13,9 @@
 //  limitations under the License.
 // -------------------------------------------------------------------------------------------------
 
+// Under development
+#![allow(dead_code)]
+
 //! Represents a ladder of price levels for one side of an order book.
 
 use std::{
@@ -26,7 +29,7 @@ use nautilus_core::nanos::UnixNanos;
 use crate::{
     data::order::{BookOrder, OrderId},
     enums::{OrderSide, OrderSideSpecified},
-    orderbook::level::Level,
+    orderbook::level::BookLevel,
     types::{price::Price, quantity::Quantity},
 };
 
@@ -78,13 +81,13 @@ impl Display for BookPrice {
 
 /// Represents a ladder of price levels for one side of an order book.
 #[derive(Clone, Debug)]
-pub struct Ladder {
+pub(crate) struct BookLadder {
     pub side: OrderSide,
-    pub levels: BTreeMap<BookPrice, Level>,
+    pub levels: BTreeMap<BookPrice, BookLevel>,
     pub cache: HashMap<u64, BookPrice>,
 }
 
-impl Ladder {
+impl BookLadder {
     /// Creates a new [`Ladder`] instance.
     #[must_use]
     pub fn new(side: OrderSide) -> Self {
@@ -95,27 +98,32 @@ impl Ladder {
         }
     }
 
+    /// Returns the number of price levels in the ladder.
     #[must_use]
     pub fn len(&self) -> usize {
         self.levels.len()
     }
 
+    /// Returns true if the ladder has no price levels.
     #[must_use]
     pub fn is_empty(&self) -> bool {
         self.levels.is_empty()
     }
 
+    /// Adds multiple orders to the ladder.
     pub fn add_bulk(&mut self, orders: Vec<BookOrder>) {
         for order in orders {
             self.add(order);
         }
     }
 
+    /// Removes all orders and price levels from the ladder.
     pub fn clear(&mut self) {
         self.levels.clear();
         self.cache.clear();
     }
 
+    /// Adds an order to the ladder at its price level.
     pub fn add(&mut self, order: BookOrder) {
         let book_price = order.to_book_price();
         self.cache.insert(order.order_id, book_price);
@@ -125,12 +133,13 @@ impl Ladder {
                 level.add(order);
             }
             None => {
-                let level = Level::from_order(order);
+                let level = BookLevel::from_order(order);
                 self.levels.insert(book_price, level);
             }
         }
     }
 
+    /// Updates an existing order in the ladder, moving it to a new price level if needed.
     pub fn update(&mut self, order: BookOrder) {
         let price = self.cache.get(&order.order_id).copied();
         if let Some(price) = price {
@@ -153,10 +162,12 @@ impl Ladder {
         self.add(order);
     }
 
+    /// Deletes an order from the ladder.
     pub fn delete(&mut self, order: BookOrder, sequence: u64, ts_event: UnixNanos) {
         self.remove(order.order_id, sequence, ts_event);
     }
 
+    /// Removes an order by its ID from the ladder.
     pub fn remove(&mut self, order_id: OrderId, sequence: u64, ts_event: UnixNanos) {
         if let Some(price) = self.cache.remove(&order_id) {
             if let Some(level) = self.levels.get_mut(&price) {
@@ -168,27 +179,35 @@ impl Ladder {
         }
     }
 
+    /// Returns the total size of all orders in the ladder.
     #[must_use]
     pub fn sizes(&self) -> f64 {
-        self.levels.values().map(super::level::Level::size).sum()
+        self.levels
+            .values()
+            .map(super::level::BookLevel::size)
+            .sum()
     }
 
+    /// Returns the total value exposure (price * size) of all orders in the ladder.
     #[must_use]
     pub fn exposures(&self) -> f64 {
         self.levels
             .values()
-            .map(super::level::Level::exposure)
+            .map(super::level::BookLevel::exposure)
             .sum()
     }
 
+    /// Returns the best price level in the ladder.
     #[must_use]
-    pub fn top(&self) -> Option<&Level> {
+    pub fn top(&self) -> Option<&BookLevel> {
         match self.levels.iter().next() {
             Some((_, l)) => Option::Some(l),
             None => Option::None,
         }
     }
 
+    /// Simulates fills for an order against this ladder's liquidity.
+    /// Returns a list of (price, size) tuples representing the simulated fills.
     #[must_use]
     pub fn simulate_fills(&self, order: &BookOrder) -> Vec<(Price, Quantity)> {
         let is_reversed = self.side == OrderSide::Buy;
@@ -234,7 +253,7 @@ mod tests {
     use crate::{
         data::order::BookOrder,
         enums::OrderSide,
-        orderbook::ladder::{BookPrice, Ladder},
+        orderbook::ladder::{BookLadder, BookPrice},
         types::{price::Price, quantity::Quantity},
     };
 
@@ -265,7 +284,7 @@ mod tests {
 
     #[rstest]
     fn test_add_single_order() {
-        let mut ladder = Ladder::new(OrderSide::Buy);
+        let mut ladder = BookLadder::new(OrderSide::Buy);
         let order = BookOrder::new(OrderSide::Buy, Price::from("10.00"), Quantity::from(20), 0);
 
         ladder.add(order);
@@ -277,7 +296,7 @@ mod tests {
 
     #[rstest]
     fn test_add_multiple_buy_orders() {
-        let mut ladder = Ladder::new(OrderSide::Buy);
+        let mut ladder = BookLadder::new(OrderSide::Buy);
         let order1 = BookOrder::new(OrderSide::Buy, Price::from("10.00"), Quantity::from(20), 0);
         let order2 = BookOrder::new(OrderSide::Buy, Price::from("9.00"), Quantity::from(30), 1);
         let order3 = BookOrder::new(OrderSide::Buy, Price::from("9.00"), Quantity::from(50), 2);
@@ -292,7 +311,7 @@ mod tests {
 
     #[rstest]
     fn test_add_multiple_sell_orders() {
-        let mut ladder = Ladder::new(OrderSide::Sell);
+        let mut ladder = BookLadder::new(OrderSide::Sell);
         let order1 = BookOrder::new(OrderSide::Sell, Price::from("11.00"), Quantity::from(20), 0);
         let order2 = BookOrder::new(OrderSide::Sell, Price::from("12.00"), Quantity::from(30), 1);
         let order3 = BookOrder::new(OrderSide::Sell, Price::from("12.00"), Quantity::from(50), 2);
@@ -312,7 +331,7 @@ mod tests {
 
     #[rstest]
     fn test_add_to_same_price_level() {
-        let mut ladder = Ladder::new(OrderSide::Buy);
+        let mut ladder = BookLadder::new(OrderSide::Buy);
         let order1 = BookOrder::new(OrderSide::Buy, Price::from("10.00"), Quantity::from(20), 1);
         let order2 = BookOrder::new(OrderSide::Buy, Price::from("10.00"), Quantity::from(30), 2);
 
@@ -326,7 +345,7 @@ mod tests {
 
     #[rstest]
     fn test_add_descending_buy_orders() {
-        let mut ladder = Ladder::new(OrderSide::Buy);
+        let mut ladder = BookLadder::new(OrderSide::Buy);
         let order1 = BookOrder::new(OrderSide::Buy, Price::from("9.00"), Quantity::from(20), 1);
         let order2 = BookOrder::new(OrderSide::Buy, Price::from("8.00"), Quantity::from(30), 2);
 
@@ -338,7 +357,7 @@ mod tests {
 
     #[rstest]
     fn test_add_ascending_sell_orders() {
-        let mut ladder = Ladder::new(OrderSide::Sell);
+        let mut ladder = BookLadder::new(OrderSide::Sell);
         let order1 = BookOrder::new(OrderSide::Sell, Price::from("8.00"), Quantity::from(20), 1);
         let order2 = BookOrder::new(OrderSide::Sell, Price::from("9.00"), Quantity::from(30), 2);
 
@@ -350,7 +369,7 @@ mod tests {
 
     #[rstest]
     fn test_update_buy_order_price() {
-        let mut ladder = Ladder::new(OrderSide::Buy);
+        let mut ladder = BookLadder::new(OrderSide::Buy);
         let order = BookOrder::new(OrderSide::Buy, Price::from("11.00"), Quantity::from(20), 1);
 
         ladder.add(order);
@@ -365,7 +384,7 @@ mod tests {
 
     #[rstest]
     fn test_update_sell_order_price() {
-        let mut ladder = Ladder::new(OrderSide::Sell);
+        let mut ladder = BookLadder::new(OrderSide::Sell);
         let order = BookOrder::new(OrderSide::Sell, Price::from("11.00"), Quantity::from(20), 1);
 
         ladder.add(order);
@@ -381,7 +400,7 @@ mod tests {
 
     #[rstest]
     fn test_update_buy_order_size() {
-        let mut ladder = Ladder::new(OrderSide::Buy);
+        let mut ladder = BookLadder::new(OrderSide::Buy);
         let order = BookOrder::new(OrderSide::Buy, Price::from("11.00"), Quantity::from(20), 1);
 
         ladder.add(order);
@@ -397,7 +416,7 @@ mod tests {
 
     #[rstest]
     fn test_update_sell_order_size() {
-        let mut ladder = Ladder::new(OrderSide::Sell);
+        let mut ladder = BookLadder::new(OrderSide::Sell);
         let order = BookOrder::new(OrderSide::Sell, Price::from("11.00"), Quantity::from(20), 1);
 
         ladder.add(order);
@@ -413,7 +432,7 @@ mod tests {
 
     #[rstest]
     fn test_delete_non_existing_order() {
-        let mut ladder = Ladder::new(OrderSide::Buy);
+        let mut ladder = BookLadder::new(OrderSide::Buy);
         let order = BookOrder::new(OrderSide::Buy, Price::from("10.00"), Quantity::from(20), 1);
 
         ladder.delete(order, 0, 0.into());
@@ -423,7 +442,7 @@ mod tests {
 
     #[rstest]
     fn test_delete_buy_order() {
-        let mut ladder = Ladder::new(OrderSide::Buy);
+        let mut ladder = BookLadder::new(OrderSide::Buy);
         let order = BookOrder::new(OrderSide::Buy, Price::from("11.00"), Quantity::from(20), 1);
 
         ladder.add(order);
@@ -439,7 +458,7 @@ mod tests {
 
     #[rstest]
     fn test_delete_sell_order() {
-        let mut ladder = Ladder::new(OrderSide::Sell);
+        let mut ladder = BookLadder::new(OrderSide::Sell);
         let order = BookOrder::new(OrderSide::Sell, Price::from("10.00"), Quantity::from(10), 1);
 
         ladder.add(order);
@@ -455,7 +474,7 @@ mod tests {
 
     #[rstest]
     fn test_simulate_fills_with_empty_book() {
-        let ladder = Ladder::new(OrderSide::Buy);
+        let ladder = BookLadder::new(OrderSide::Buy);
         let order = BookOrder::new(OrderSide::Buy, Price::max(2), Quantity::from(500), 1);
 
         let fills = ladder.simulate_fills(&order);
@@ -471,7 +490,7 @@ mod tests {
         #[case] price: Price,
         #[case] ladder_side: OrderSide,
     ) {
-        let ladder = Ladder::new(ladder_side);
+        let ladder = BookLadder::new(ladder_side);
         let order = BookOrder {
             price, // <-- Simulate a MARKET order
             size: Quantity::from(500),
@@ -492,7 +511,7 @@ mod tests {
         #[case] ladder_side: OrderSide,
         #[case] ladder_price: Price,
     ) {
-        let mut ladder = Ladder::new(ladder_side);
+        let mut ladder = BookLadder::new(ladder_side);
 
         ladder.add(BookOrder {
             price: ladder_price,
@@ -515,7 +534,7 @@ mod tests {
 
     #[rstest]
     fn test_simulate_order_fills_sell_when_far_from_market() {
-        let mut ladder = Ladder::new(OrderSide::Buy);
+        let mut ladder = BookLadder::new(OrderSide::Buy);
 
         ladder.add(BookOrder {
             price: Price::from("100.00"),
@@ -538,7 +557,7 @@ mod tests {
 
     #[rstest]
     fn test_simulate_order_fills_buy() {
-        let mut ladder = Ladder::new(OrderSide::Sell);
+        let mut ladder = BookLadder::new(OrderSide::Sell);
 
         ladder.add_bulk(vec![
             BookOrder {
@@ -587,7 +606,7 @@ mod tests {
 
     #[rstest]
     fn test_simulate_order_fills_sell() {
-        let mut ladder = Ladder::new(OrderSide::Buy);
+        let mut ladder = BookLadder::new(OrderSide::Buy);
 
         ladder.add_bulk(vec![
             BookOrder {
@@ -636,7 +655,7 @@ mod tests {
 
     #[rstest]
     fn test_simulate_order_fills_sell_with_size_at_limit_of_precision() {
-        let mut ladder = Ladder::new(OrderSide::Buy);
+        let mut ladder = BookLadder::new(OrderSide::Buy);
 
         ladder.add_bulk(vec![
             BookOrder {
@@ -688,8 +707,8 @@ mod tests {
         let max_price = Price::max(1);
         let min_price = Price::min(1);
 
-        let mut ladder_buy = Ladder::new(OrderSide::Buy);
-        let mut ladder_sell = Ladder::new(OrderSide::Sell);
+        let mut ladder_buy = BookLadder::new(OrderSide::Buy);
+        let mut ladder_sell = BookLadder::new(OrderSide::Sell);
 
         let order_buy = BookOrder::new(OrderSide::Buy, min_price, Quantity::from(1), 1);
         let order_sell = BookOrder::new(OrderSide::Sell, max_price, Quantity::from(1), 1);
