@@ -18,6 +18,7 @@
 use std::{cmp::Ordering, collections::BTreeMap};
 
 use nautilus_core::nanos::UnixNanos;
+use rust_decimal::Decimal;
 
 use crate::{
     data::order::{BookOrder, OrderId},
@@ -34,13 +35,13 @@ use crate::{
     feature = "python",
     pyo3::pyclass(module = "nautilus_trader.core.nautilus_pyo3.model")
 )]
-pub struct Level {
+pub struct BookLevel {
     pub price: BookPrice,
     pub orders: BTreeMap<OrderId, BookOrder>,
     insertion_order: Vec<OrderId>,
 }
 
-impl Level {
+impl BookLevel {
     /// Creates a new [`Level`] instance.
     #[must_use]
     pub fn new(price: BookPrice) -> Self {
@@ -51,6 +52,7 @@ impl Level {
         }
     }
 
+    /// Creates a new price level from an order, using the order's price and side.
     #[must_use]
     pub fn from_order(order: BookOrder) -> Self {
         let mut level = Self {
@@ -62,16 +64,19 @@ impl Level {
         level
     }
 
+    /// Returns the number of orders at this price level.
     #[must_use]
     pub fn len(&self) -> usize {
         self.orders.len()
     }
 
+    /// Returns true if this price level has no orders.
     #[must_use]
     pub fn is_empty(&self) -> bool {
         self.orders.is_empty()
     }
 
+    /// Returns a reference to the first order at this price level in FIFO order.
     #[must_use]
     pub fn first(&self) -> Option<&BookOrder> {
         self.insertion_order
@@ -79,7 +84,7 @@ impl Level {
             .and_then(|&id| self.orders.get(&id))
     }
 
-    /// Returns the orders in the insertion order.
+    /// Returns all orders at this price level in FIFO insertion order.
     #[must_use]
     pub fn get_orders(&self) -> Vec<BookOrder> {
         self.insertion_order
@@ -89,16 +94,25 @@ impl Level {
             .collect()
     }
 
+    /// Returns the total size of all orders at this price level as a float.
     #[must_use]
     pub fn size(&self) -> f64 {
         self.orders.values().map(|o| o.size.as_f64()).sum()
     }
 
+    /// Returns the total size of all orders at this price level as raw integer units.
     #[must_use]
     pub fn size_raw(&self) -> u64 {
         self.orders.values().map(|o| o.size.raw).sum()
     }
 
+    /// Returns the total size of all orders at this price level as a decimal.
+    #[must_use]
+    pub fn size_decimal(&self) -> Decimal {
+        self.orders.values().map(|o| o.size.as_decimal()).sum()
+    }
+
+    /// Returns the total exposure (price * size) of all orders at this price level as a float.
     #[must_use]
     pub fn exposure(&self) -> f64 {
         self.orders
@@ -107,6 +121,7 @@ impl Level {
             .sum()
     }
 
+    /// Returns the total exposure (price * size) of all orders at this price level as raw integer units.
     #[must_use]
     pub fn exposure_raw(&self) -> u64 {
         self.orders
@@ -115,6 +130,7 @@ impl Level {
             .sum()
     }
 
+    /// Adds multiple orders to this price level in FIFO order. Orders must match the level's price.
     pub fn add_bulk(&mut self, orders: Vec<BookOrder>) {
         self.insertion_order
             .extend(orders.iter().map(|o| o.order_id));
@@ -125,6 +141,7 @@ impl Level {
         }
     }
 
+    /// Adds an order to this price level. Order must match the level's price.
     pub fn add(&mut self, order: BookOrder) {
         self.check_order_for_this_level(&order);
 
@@ -132,6 +149,8 @@ impl Level {
         self.insertion_order.push(order.order_id);
     }
 
+    /// Updates an existing order at this price level. Updated order must match the level's price.
+    /// Removes the order if size becomes zero.
     pub fn update(&mut self, order: BookOrder) {
         self.check_order_for_this_level(&order);
 
@@ -143,11 +162,13 @@ impl Level {
         }
     }
 
+    /// Deletes an order from this price level.
     pub fn delete(&mut self, order: &BookOrder) {
         self.orders.remove(&order.order_id);
         self.update_insertion_order();
     }
 
+    /// Removes an order by its ID. Panics if the order doesn't exist.
     pub fn remove_by_id(&mut self, order_id: OrderId, sequence: u64, ts_event: UnixNanos) {
         assert!(
             self.orders.remove(&order_id).is_some(),
@@ -162,18 +183,24 @@ impl Level {
     }
 
     fn update_insertion_order(&mut self) {
-        self.insertion_order
-            .retain(|&id| self.orders.contains_key(&id));
+        if self
+            .insertion_order
+            .iter()
+            .any(|id| !self.orders.contains_key(id))
+        {
+            self.insertion_order
+                .retain(|&id| self.orders.contains_key(&id));
+        }
     }
 }
 
-impl PartialEq for Level {
+impl PartialEq for BookLevel {
     fn eq(&self, other: &Self) -> bool {
         self.price == other.price
     }
 }
 
-impl PartialOrd for Level {
+impl PartialOrd for BookLevel {
     fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
         Some(self.cmp(other))
     }
@@ -195,7 +222,7 @@ impl PartialOrd for Level {
     }
 }
 
-impl Ord for Level {
+impl Ord for BookLevel {
     fn cmp(&self, other: &Self) -> Ordering {
         self.price.cmp(&other.price)
     }
@@ -207,39 +234,72 @@ impl Ord for Level {
 #[cfg(test)]
 mod tests {
     use rstest::rstest;
+    use rust_decimal_macros::dec;
 
     use crate::{
         data::order::BookOrder,
         enums::OrderSide,
-        orderbook::{ladder::BookPrice, level::Level},
+        orderbook::{ladder::BookPrice, level::BookLevel},
         types::{price::Price, quantity::Quantity},
     };
 
     #[rstest]
     fn test_empty_level() {
-        let level = Level::new(BookPrice::new(Price::from("1.00"), OrderSide::Buy));
+        let level = BookLevel::new(BookPrice::new(Price::from("1.00"), OrderSide::Buy));
         assert!(level.first().is_none());
     }
 
+    #[rstest]
+    fn test_level_from_order() {
+        let order = BookOrder::new(OrderSide::Buy, Price::from("1.00"), Quantity::from(10), 1);
+        let level = BookLevel::from_order(order);
+
+        assert_eq!(level.price.value, Price::from("1.00"));
+        assert_eq!(level.price.side, OrderSide::Buy);
+        assert_eq!(level.len(), 1);
+        assert_eq!(level.first().unwrap(), &order);
+        assert_eq!(level.size(), 10.0);
+    }
+
+    #[rstest]
+    #[should_panic(expected = "assertion `left == right` failed")]
+    fn test_add_order_incorrect_price_level() {
+        let mut level = BookLevel::new(BookPrice::new(Price::from("1.00"), OrderSide::Buy));
+        let incorrect_price_order =
+            BookOrder::new(OrderSide::Buy, Price::from("2.00"), Quantity::from(10), 1);
+        level.add(incorrect_price_order);
+    }
+
+    #[rstest]
+    #[should_panic(expected = "assertion `left == right` failed")]
+    fn test_add_bulk_orders_incorrect_price() {
+        let mut level = BookLevel::new(BookPrice::new(Price::from("1.00"), OrderSide::Buy));
+        let orders = vec![
+            BookOrder::new(OrderSide::Buy, Price::from("1.00"), Quantity::from(10), 1),
+            BookOrder::new(OrderSide::Buy, Price::from("2.00"), Quantity::from(20), 2), // Incorrect price
+        ];
+        level.add_bulk(orders);
+    }
+
     #[rstest]
     fn test_comparisons_bid_side() {
-        let level0 = Level::new(BookPrice::new(Price::from("1.00"), OrderSide::Buy));
-        let level1 = Level::new(BookPrice::new(Price::from("1.01"), OrderSide::Buy));
+        let level0 = BookLevel::new(BookPrice::new(Price::from("1.00"), OrderSide::Buy));
+        let level1 = BookLevel::new(BookPrice::new(Price::from("1.01"), OrderSide::Buy));
         assert_eq!(level0, level0);
         assert!(level0 > level1);
     }
 
     #[rstest]
     fn test_comparisons_ask_side() {
-        let level0 = Level::new(BookPrice::new(Price::from("1.00"), OrderSide::Sell));
-        let level1 = Level::new(BookPrice::new(Price::from("1.01"), OrderSide::Sell));
+        let level0 = BookLevel::new(BookPrice::new(Price::from("1.00"), OrderSide::Sell));
+        let level1 = BookLevel::new(BookPrice::new(Price::from("1.01"), OrderSide::Sell));
         assert_eq!(level0, level0);
         assert!(level0 < level1);
     }
 
     #[rstest]
-    fn test_add_one_order() {
-        let mut level = Level::new(BookPrice::new(Price::from("1.00"), OrderSide::Buy));
+    fn test_add_single_order() {
+        let mut level = BookLevel::new(BookPrice::new(Price::from("1.00"), OrderSide::Buy));
         let order = BookOrder::new(OrderSide::Buy, Price::from("1.00"), Quantity::from(10), 0);
 
         level.add(order);
@@ -251,7 +311,7 @@ mod tests {
 
     #[rstest]
     fn test_add_multiple_orders() {
-        let mut level = Level::new(BookPrice::new(Price::from("2.00"), OrderSide::Buy));
+        let mut level = BookLevel::new(BookPrice::new(Price::from("2.00"), OrderSide::Buy));
         let order1 = BookOrder::new(OrderSide::Buy, Price::from("2.00"), Quantity::from(10), 0);
         let order2 = BookOrder::new(OrderSide::Buy, Price::from("2.00"), Quantity::from(20), 1);
 
@@ -263,9 +323,24 @@ mod tests {
         assert_eq!(level.first().unwrap(), &order1);
     }
 
+    #[rstest]
+    fn test_get_orders() {
+        let mut level = BookLevel::new(BookPrice::new(Price::from("1.00"), OrderSide::Buy));
+        let order1 = BookOrder::new(OrderSide::Buy, Price::from("1.00"), Quantity::from(10), 1);
+        let order2 = BookOrder::new(OrderSide::Buy, Price::from("1.00"), Quantity::from(20), 2);
+
+        level.add(order1);
+        level.add(order2);
+
+        let orders = level.get_orders();
+        assert_eq!(orders.len(), 2);
+        assert_eq!(orders[0], order1); // Checks FIFO order maintained
+        assert_eq!(orders[1], order2);
+    }
+
     #[rstest]
     fn test_update_order() {
-        let mut level = Level::new(BookPrice::new(Price::from("1.00"), OrderSide::Buy));
+        let mut level = BookLevel::new(BookPrice::new(Price::from("1.00"), OrderSide::Buy));
         let order1 = BookOrder::new(OrderSide::Buy, Price::from("1.00"), Quantity::from(10), 0);
         let order2 = BookOrder::new(OrderSide::Buy, Price::from("1.00"), Quantity::from(20), 0);
 
@@ -276,9 +351,46 @@ mod tests {
         assert_eq!(level.exposure(), 20.0);
     }
 
+    #[rstest]
+    fn test_fifo_order_after_updates() {
+        let mut level = BookLevel::new(BookPrice::new(Price::from("1.00"), OrderSide::Buy));
+
+        let order1 = BookOrder::new(OrderSide::Buy, Price::from("1.00"), Quantity::from(10), 1);
+        let order2 = BookOrder::new(OrderSide::Buy, Price::from("1.00"), Quantity::from(20), 2);
+
+        level.add(order1.clone());
+        level.add(order2.clone());
+
+        // Update order1 size
+        let updated_order1 =
+            BookOrder::new(OrderSide::Buy, Price::from("1.00"), Quantity::from(15), 1);
+        level.update(updated_order1.clone());
+
+        let orders = level.get_orders();
+        assert_eq!(orders.len(), 2);
+        assert_eq!(orders[0], updated_order1); // First order still first
+        assert_eq!(orders[1], order2); // Second order still second
+    }
+
+    #[rstest]
+    #[should_panic(expected = "assertion `left == right` failed")]
+    fn test_update_order_incorrect_price() {
+        let mut level = BookLevel::new(BookPrice::new(Price::from("1.00"), OrderSide::Buy));
+
+        // Add initial order at correct price level
+        let initial_order =
+            BookOrder::new(OrderSide::Buy, Price::from("1.00"), Quantity::from(10), 1);
+        level.add(initial_order);
+
+        // Attempt to update with order at incorrect price level
+        let updated_order =
+            BookOrder::new(OrderSide::Buy, Price::from("2.00"), Quantity::from(20), 1);
+        level.update(updated_order);
+    }
+
     #[rstest]
     fn test_update_order_with_zero_size() {
-        let mut level = Level::new(BookPrice::new(Price::from("1.00"), OrderSide::Buy));
+        let mut level = BookLevel::new(BookPrice::new(Price::from("1.00"), OrderSide::Buy));
         let order1 = BookOrder::new(OrderSide::Buy, Price::from("1.00"), Quantity::from(10), 0);
         let order2 = BookOrder::new(OrderSide::Buy, Price::from("1.00"), Quantity::zero(0), 0);
 
@@ -289,9 +401,30 @@ mod tests {
         assert_eq!(level.exposure(), 0.0);
     }
 
+    #[rstest]
+    fn test_update_insertion_order_optimization() {
+        let mut level = BookLevel::new(BookPrice::new(Price::from("1.00"), OrderSide::Buy));
+
+        // Add orders
+        let order1 = BookOrder::new(OrderSide::Buy, Price::from("1.00"), Quantity::from(10), 1);
+        let order2 = BookOrder::new(OrderSide::Buy, Price::from("1.00"), Quantity::from(20), 2);
+        level.add(order1);
+        level.add(order2);
+
+        // Update with same orders - should not rebuild insertion_order
+        let initial_insertion_order = level.insertion_order.clone();
+        level.update_insertion_order();
+        assert_eq!(level.insertion_order, initial_insertion_order);
+
+        // Remove an order
+        level.orders.remove(&1);
+        level.update_insertion_order();
+        assert_eq!(level.insertion_order, vec![2]);
+    }
+
     #[rstest]
     fn test_delete_order() {
-        let mut level = Level::new(BookPrice::new(Price::from("1.00"), OrderSide::Buy));
+        let mut level = BookLevel::new(BookPrice::new(Price::from("1.00"), OrderSide::Buy));
         let order1_id = 0;
         let order1 = BookOrder::new(
             OrderSide::Buy,
@@ -317,8 +450,8 @@ mod tests {
     }
 
     #[rstest]
-    fn test_remove_order() {
-        let mut level = Level::new(BookPrice::new(Price::from("1.00"), OrderSide::Buy));
+    fn test_remove_order_by_id() {
+        let mut level = BookLevel::new(BookPrice::new(Price::from("1.00"), OrderSide::Buy));
         let order1_id = 0;
         let order1 = BookOrder::new(
             OrderSide::Buy,
@@ -345,7 +478,7 @@ mod tests {
 
     #[rstest]
     fn test_add_bulk_orders() {
-        let mut level = Level::new(BookPrice::new(Price::from("2.00"), OrderSide::Buy));
+        let mut level = BookLevel::new(BookPrice::new(Price::from("2.00"), OrderSide::Buy));
         let order1_id = 0;
         let order1 = BookOrder::new(
             OrderSide::Buy,
@@ -368,18 +501,34 @@ mod tests {
         assert_eq!(level.exposure(), 60.0);
     }
 
+    #[rstest]
+    fn test_maximum_order_id() {
+        let mut level = BookLevel::new(BookPrice::new(Price::from("1.00"), OrderSide::Buy));
+
+        let order = BookOrder::new(
+            OrderSide::Buy,
+            Price::from("1.00"),
+            Quantity::from(10),
+            u64::MAX,
+        );
+        level.add(order.clone());
+
+        assert_eq!(level.len(), 1);
+        assert_eq!(level.first().unwrap(), &order);
+    }
+
     #[rstest]
     #[should_panic(
         expected = "Integrity error: order not found: order_id=1, sequence=2, ts_event=3"
     )]
     fn test_remove_nonexistent_order() {
-        let mut level = Level::new(BookPrice::new(Price::from("1.00"), OrderSide::Buy));
+        let mut level = BookLevel::new(BookPrice::new(Price::from("1.00"), OrderSide::Buy));
         level.remove_by_id(1, 2, 3.into());
     }
 
     #[rstest]
     fn test_size() {
-        let mut level = Level::new(BookPrice::new(Price::from("1.00"), OrderSide::Buy));
+        let mut level = BookLevel::new(BookPrice::new(Price::from("1.00"), OrderSide::Buy));
         let order1 = BookOrder::new(OrderSide::Buy, Price::from("1.00"), Quantity::from(10), 0);
         let order2 = BookOrder::new(OrderSide::Buy, Price::from("1.00"), Quantity::from(15), 1);
 
@@ -390,7 +539,7 @@ mod tests {
 
     #[rstest]
     fn test_size_raw() {
-        let mut level = Level::new(BookPrice::new(Price::from("2.00"), OrderSide::Buy));
+        let mut level = BookLevel::new(BookPrice::new(Price::from("2.00"), OrderSide::Buy));
         let order1 = BookOrder::new(OrderSide::Buy, Price::from("2.00"), Quantity::from(10), 0);
         let order2 = BookOrder::new(OrderSide::Buy, Price::from("2.00"), Quantity::from(20), 1);
 
@@ -399,9 +548,20 @@ mod tests {
         assert_eq!(level.size_raw(), 30_000_000_000);
     }
 
+    #[rstest]
+    fn test_size_decimal() {
+        let mut level = BookLevel::new(BookPrice::new(Price::from("2.00"), OrderSide::Buy));
+        let order1 = BookOrder::new(OrderSide::Buy, Price::from("2.00"), Quantity::from(10), 0);
+        let order2 = BookOrder::new(OrderSide::Buy, Price::from("2.00"), Quantity::from(20), 1);
+
+        level.add(order1);
+        level.add(order2);
+        assert_eq!(level.size_decimal(), dec!(30.0));
+    }
+
     #[rstest]
     fn test_exposure() {
-        let mut level = Level::new(BookPrice::new(Price::from("2.00"), OrderSide::Buy));
+        let mut level = BookLevel::new(BookPrice::new(Price::from("2.00"), OrderSide::Buy));
         let order1 = BookOrder::new(OrderSide::Buy, Price::from("2.00"), Quantity::from(10), 0);
         let order2 = BookOrder::new(OrderSide::Buy, Price::from("2.00"), Quantity::from(20), 1);
 
@@ -412,7 +572,7 @@ mod tests {
 
     #[rstest]
     fn test_exposure_raw() {
-        let mut level = Level::new(BookPrice::new(Price::from("2.00"), OrderSide::Buy));
+        let mut level = BookLevel::new(BookPrice::new(Price::from("2.00"), OrderSide::Buy));
         let order1 = BookOrder::new(OrderSide::Buy, Price::from("2.00"), Quantity::from(10), 0);
         let order2 = BookOrder::new(OrderSide::Buy, Price::from("2.00"), Quantity::from(20), 1);
 
