@@ -56,6 +56,12 @@ pub enum OrderAny {
     TrailingStopMarket(TrailingStopMarketOrder),
 }
 
+impl Default for OrderAny {
+    fn default() -> Self {
+        Self::Limit(LimitOrder::default())
+    }
+}
+
 impl OrderAny {
     /// Applies the given `event` to the order.
     pub fn apply(&mut self, event: OrderEventAny) -> Result<(), OrderError> {
@@ -141,6 +147,21 @@ impl OrderAny {
         }
     }
 
+    #[must_use]
+    pub fn last_event(&self) -> &OrderEventAny {
+        match self {
+            Self::Limit(order) => order.last_event(),
+            Self::LimitIfTouched(order) => order.last_event(),
+            Self::Market(order) => order.last_event(),
+            Self::MarketIfTouched(order) => order.last_event(),
+            Self::MarketToLimit(order) => order.last_event(),
+            Self::StopLimit(order) => order.last_event(),
+            Self::StopMarket(order) => order.last_event(),
+            Self::TrailingStopLimit(order) => order.last_event(),
+            Self::TrailingStopMarket(order) => order.last_event(),
+        }
+    }
+
     #[must_use]
     pub fn trader_id(&self) -> TraderId {
         match self {
@@ -598,6 +619,9 @@ impl PartialEq for OrderAny {
     }
 }
 
+// TODO: fix equality
+impl Eq for OrderAny {}
+
 impl Display for OrderAny {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         write!(
@@ -686,9 +710,8 @@ impl AsRef<StopMarketOrder> for OrderAny {
         match self {
             OrderAny::StopMarket(ref order) => order,
             _ => panic!(
-                "Invalid `OrderAny` not `{}`, was {:?}",
+                "Invalid `OrderAny` not `{}`, was {self:?}",
                 stringify!(StopMarketOrder),
-                self
             ),
         }
     }
