@@ -13,8 +13,11 @@
 //  limitations under the License.
 // -------------------------------------------------------------------------------------------------
 
+use std::collections::HashMap;
+
 use nautilus_core::python::{to_pyruntime_err, to_pyvalue_err};
 use pyo3::prelude::*;
+use rust_decimal::Decimal;
 
 use crate::{
     data::{
@@ -23,7 +26,7 @@ use crate::{
     },
     enums::{BookType, OrderSide},
     identifiers::InstrumentId,
-    orderbook::{analysis::book_check_integrity, book::OrderBook, level::Level},
+    orderbook::{analysis::book_check_integrity, book::OrderBook, level::BookLevel},
     types::{price::Price, quantity::Quantity},
 };
 
@@ -147,17 +150,37 @@ impl OrderBook {
     }
 
     #[pyo3(name = "bids")]
-    fn py_bids(&self) -> Vec<Level> {
+    fn py_bids(&self) -> Vec<BookLevel> {
         // TODO: Improve efficiency
         self.bids().map(|level_ref| (*level_ref).clone()).collect()
     }
 
     #[pyo3(name = "asks")]
-    fn py_asks(&self) -> Vec<Level> {
+    fn py_asks(&self) -> Vec<BookLevel> {
         // TODO: Improve efficiency
         self.asks().map(|level_ref| (*level_ref).clone()).collect()
     }
 
+    #[pyo3(name = "bids_to_dict")]
+    fn py_bids_to_dict(&self) -> HashMap<Decimal, Decimal> {
+        self.bids_as_map()
+    }
+
+    #[pyo3(name = "asks_to_dict")]
+    fn py_asks_to_dict(&self) -> HashMap<Decimal, Decimal> {
+        self.asks_as_map()
+    }
+
+    #[pyo3(name = "group_bids")]
+    pub fn py_group_bids(&self, group_size: Decimal, depth: usize) -> HashMap<Decimal, Decimal> {
+        self.group_bids(group_size, depth)
+    }
+
+    #[pyo3(name = "group_asks")]
+    pub fn py_group_asks(&self, group_size: Decimal, depth: usize) -> HashMap<Decimal, Decimal> {
+        self.group_asks(group_size, depth)
+    }
+
     #[pyo3(name = "best_bid_price")]
     fn py_best_bid_price(&self) -> Option<Price> {
         self.best_bid_price()
