@@ -126,6 +126,12 @@ impl Currency {
         Ok(())
     }
 
+    /// Attempts to parse a [`Currency`] from a string, returning `None` if not found.
+    pub fn try_from_str(s: &str) -> Option<Self> {
+        let map_guard = CURRENCY_MAP.lock().ok()?;
+        map_guard.get(s).copied()
+    }
+
     /// Checks if the currency identified by the given `code` is a fiat currency.
     ///
     /// # Errors
@@ -211,17 +217,9 @@ impl FromStr for Currency {
     }
 }
 
-impl From<&str> for Currency {
-    fn from(value: &str) -> Self {
-        value
-            .parse()
-            .expect("Currency string representation should be valid")
-    }
-}
-
-impl From<String> for Currency {
-    fn from(value: String) -> Self {
-        Self::from(value.as_str())
+impl<T: AsRef<str>> From<T> for Currency {
+    fn from(value: T) -> Self {
+        Self::from_str(value.as_ref()).expect(FAILED)
     }
 }
 
@@ -305,6 +303,22 @@ mod tests {
         assert_eq!(currency.currency_type, CurrencyType::Crypto);
     }
 
+    #[rstest]
+    fn test_try_from_str_valid() {
+        let test_currency = Currency::new("TEST", 2, 999, "Test Currency", CurrencyType::Fiat);
+        Currency::register(test_currency, true).unwrap();
+
+        let currency = Currency::try_from_str("TEST");
+        assert!(currency.is_some());
+        assert_eq!(currency.unwrap(), test_currency);
+    }
+
+    #[rstest]
+    fn test_try_from_str_invalid() {
+        let invalid_currency = Currency::try_from_str("INVALID");
+        assert!(invalid_currency.is_none());
+    }
+
     #[rstest]
     fn test_equality() {
         let currency1 = Currency::new("USD", 2, 840, "United States dollar", CurrencyType::Fiat);
