@@ -327,12 +327,25 @@ impl FromStr for Quantity {
     }
 }
 
+// Note: we can't implement `AsRef<str>` due overlapping traits (maybe there is a way)
 impl From<&str> for Quantity {
     fn from(value: &str) -> Self {
         Self::from_str(value).expect("Valid string input for `Quantity`")
     }
 }
 
+impl From<String> for Quantity {
+    fn from(value: String) -> Self {
+        Self::from_str(&value).expect("Valid string input for `Quantity`")
+    }
+}
+
+impl From<&String> for Quantity {
+    fn from(value: &String) -> Self {
+        Self::from_str(value).expect("Valid string input for `Quantity`")
+    }
+}
+
 impl<T: Into<u64>> AddAssign<T> for Quantity {
     fn add_assign(&mut self, other: T) {
         self.raw = self
