@@ -15,8 +15,8 @@
 
 use std::path::Path;
 
-use nautilus_adapters::databento::loader::DatabentoDataLoader;
 use nautilus_core::paths::get_workspace_root_path;
+use nautilus_databento::loader::DatabentoDataLoader;
 use nautilus_model::{enums::BookType, identifiers::InstrumentId, orderbook::book::OrderBook};
 use nautilus_test_kit::{
     common::{get_test_data_file_path, get_test_data_large_checksums_filepath},
@@ -38,7 +38,6 @@ pub fn test_order_book_databento_mbo_nasdaq() {
 
     let publishers_filepath = get_workspace_root_path()
         .join("adapters")
-        .join("src")
         .join("databento")
         .join("publishers.json");
     let _loader = DatabentoDataLoader::new(Some(publishers_filepath)).unwrap();
