@@ -16,16 +16,14 @@
 use std::{
     collections::{hash_map::DefaultHasher, HashMap},
     hash::{Hash, Hasher},
-    sync::Arc,
 };
 
 use bytes::Bytes;
-use futures_util::{stream, StreamExt};
-use pyo3::{create_exception, exceptions::PyException, prelude::*, types::PyBytes};
+use pyo3::{create_exception, exceptions::PyException, prelude::*};
 
 use crate::{
-    http::{HttpClient, HttpClientError, HttpMethod, HttpResponse, InnerHttpClient},
-    ratelimiter::{quota::Quota, RateLimiter},
+    http::{HttpClient, HttpClientError, HttpMethod, HttpResponse},
+    ratelimiter::quota::Quota,
 };
 
 // Python exception class for generic HTTP errors.
@@ -86,8 +84,9 @@ impl HttpResponse {
 
 #[pymethods]
 impl HttpClient {
-    /// Create a new HttpClient.
+    /// Creates a new HttpClient.
     ///
+    /// `default_headers`: The default headers to be used with every request.
     /// `header_keys`: The key value pairs for the given `header_keys` are retained from the responses.
     /// `keyed_quota`: A list of string quota pairs that gives quota for specific key values.
     /// `default_quota`: The default rate limiting quota for any request.
@@ -108,25 +107,15 @@ impl HttpClient {
     ///
     /// For request /foo/bar, should pass keys ["foo/bar", "foo"] for rate limiting.
     #[new]
-    #[pyo3(signature = (header_keys = Vec::new(), keyed_quotas = Vec::new(), default_quota = None))]
+    #[pyo3(signature = (default_headers = HashMap::new(), header_keys = Vec::new(), keyed_quotas = Vec::new(), default_quota = None))]
     #[must_use]
     pub fn py_new(
+        default_headers: HashMap<String, String>,
         header_keys: Vec<String>,
         keyed_quotas: Vec<(String, Quota)>,
         default_quota: Option<Quota>,
     ) -> Self {
-        let client = reqwest::Client::new();
-        let rate_limiter = Arc::new(RateLimiter::new_with_quota(default_quota, keyed_quotas));
-
-        let client = InnerHttpClient {
-            client,
-            header_keys,
-        };
-
-        Self {
-            rate_limiter,
-            client,
-        }
+        Self::new(default_headers, header_keys, keyed_quotas, default_quota)
     }
 
     /// Send an HTTP request.
@@ -150,29 +139,20 @@ impl HttpClient {
         method: HttpMethod,
         url: String,
         headers: Option<HashMap<String, String>>,
-        body: Option<Bound<'py, PyBytes>>,
+        body: Option<Vec<u8>>,
         keys: Option<Vec<String>>,
         timeout_secs: Option<u64>,
         py: Python<'py>,
     ) -> PyResult<Bound<'py, PyAny>> {
-        let headers = headers.unwrap_or_default();
-        let body_vec = body.map(|py_bytes| py_bytes.as_bytes().to_vec());
-        let keys = keys.unwrap_or_default();
         let client = self.client.clone();
         let rate_limiter = self.rate_limiter.clone();
-        let method = method.into();
+
         pyo3_async_runtimes::tokio::future_into_py(py, async move {
-            // Check keys for rate limiting quota
-            let tasks = keys.iter().map(|key| rate_limiter.until_key_ready(key));
-            stream::iter(tasks)
-                .for_each(|key| async move {
-                    key.await;
-                })
-                .await;
+            rate_limiter.await_keys_ready(keys).await;
             client
-                .send_request(method, url, headers, body_vec, timeout_secs)
+                .send_request(method.into(), url, headers, body, timeout_secs)
                 .await
-                .map_err(super::super::http::HttpClientError::into_py_err)
+                .map_err(HttpClientError::into_py_err)
         })
     }
 }
