@@ -72,7 +72,7 @@ class BinanceFuturesInstrumentProvider(InstrumentProvider):
         account_type: BinanceAccountType = BinanceAccountType.USDT_FUTURE,
         config: InstrumentProviderConfig | None = None,
         venue: Venue = BINANCE_VENUE,
-    ):
+    ) -> None:
         super().__init__(config=config)
 
         self._clock = clock
@@ -144,16 +144,13 @@ class BinanceFuturesInstrumentProvider(InstrumentProvider):
         filters: dict | None = None,
     ) -> None:
         if not instrument_ids:
-            self._log.info("No instrument IDs given for loading.")
+            self._log.warning("No instrument IDs given for loading.")
             return
 
         # Check all instrument IDs
         for instrument_id in instrument_ids:
             PyCondition.equal(instrument_id.venue, self._venue, "instrument_id.venue", "BINANCE")
 
-        filters_str = "..." if not filters else f" with filters {filters}..."
-        self._log.info(f"Loading instruments {instrument_ids}{filters_str}.")
-
         # Extract all symbol strings
         symbols = [
             str(BinanceSymbol(instrument_id.symbol.value)) for instrument_id in instrument_ids
