@@ -31,6 +31,22 @@ def raise_error(error):
     raise error
 
 
+@unique
+class BybitUnifiedMarginStatus(Enum):
+    CLASSIC_ACCOUNT = 1  # Classic account
+    UNIFIED_TRADING_ACCOUNT_1_0 = 3  # Unified trading account 1.0
+    UNIFIED_TRADING_ACCOUNT_1_0_PRO = 4  # Unified trading account 1.0 (pro version)
+    UNIFIED_TRADING_ACCOUNT_2_0 = 5  # Unified trading account 2.0
+    UNIFIED_TRADING_ACCOUNT_2_0_PRO = 6  # Unified trading account 2.0 (pro version)
+
+
+@unique
+class BybitMarginMode(Enum):
+    ISOLATED_MARGIN = "ISOLATED_MARGIN"
+    REGULAR_MARGIN = "REGULAR_MARGIN"
+    PORTFOLIO_MARGIN = "PORTFOLIO_MARGIN"
+
+
 @unique
 class BybitPositionIdx(Enum):
     # One-way mode position
@@ -223,15 +239,16 @@ class BybitEndpointType(Enum):
     ACCOUNT = "ACCOUNT"
     TRADE = "TRADE"
     POSITION = "POSITION"
+    USER = "USER"
 
 
 def check_dict_keys(key, data):
     try:
         return data[key]
-    except KeyError:
+    except KeyError as e:
         raise RuntimeError(
             f"Unrecognized Bybit {key} not found in {data}",
-        )
+        ) from e
 
 
 class BybitEnumParser:
@@ -452,7 +469,7 @@ class BybitEnumParser:
         # fmt: on
         self.bybit_to_nautilus_trigger_type = {
             BybitTriggerType.NONE: TriggerType.NO_TRIGGER,
-            BybitTriggerType.LAST_PRICE: TriggerType.LAST_TRADE,
+            BybitTriggerType.LAST_PRICE: TriggerType.LAST_PRICE,
             BybitTriggerType.MARK_PRICE: TriggerType.MARK_PRICE,
             BybitTriggerType.INDEX_PRICE: TriggerType.INDEX_PRICE,
         }
@@ -489,6 +506,23 @@ class BybitEnumParser:
             TimeInForce.FOK,
         }
 
+        # trigger direction
+        self.trigger_direction_map_buy = {
+            OrderType.STOP_MARKET: BybitTriggerDirection.RISES_TO,
+            OrderType.STOP_LIMIT: BybitTriggerDirection.RISES_TO,
+            OrderType.MARKET_IF_TOUCHED: BybitTriggerDirection.RISES_TO,
+            OrderType.TRAILING_STOP_MARKET: BybitTriggerDirection.RISES_TO,
+            OrderType.LIMIT_IF_TOUCHED: BybitTriggerDirection.FALLS_TO,
+        }
+
+        self.trigger_direction_map_sell = {
+            OrderType.STOP_MARKET: BybitTriggerDirection.FALLS_TO,
+            OrderType.STOP_LIMIT: BybitTriggerDirection.FALLS_TO,
+            OrderType.MARKET_IF_TOUCHED: BybitTriggerDirection.FALLS_TO,
+            OrderType.TRAILING_STOP_MARKET: BybitTriggerDirection.FALLS_TO,
+            OrderType.LIMIT_IF_TOUCHED: BybitTriggerDirection.RISES_TO,
+        }
+
     def parse_bybit_order_status(
         self,
         order_type: OrderType,
@@ -520,10 +554,10 @@ class BybitEnumParser:
     def parse_nautilus_time_in_force(self, time_in_force: TimeInForce) -> BybitTimeInForce:
         try:
             return self.nautilus_to_bybit_time_in_force[time_in_force]
-        except KeyError:
+        except KeyError as e:
             raise RuntimeError(
                 f"unrecognized Bybit time in force, was {time_in_force_to_str(time_in_force)}",  # pragma: no cover
-            )
+            ) from e
 
     def parse_nautilus_trigger_type(self, trigger_type: TriggerType) -> BybitTriggerType:
         return check_dict_keys(trigger_type, self.nautilus_to_bybit_trigger_type)
@@ -531,39 +565,16 @@ class BybitEnumParser:
     def parse_bybit_trigger_type(self, trigger_type: BybitTriggerType) -> TriggerType:
         return check_dict_keys(trigger_type, self.bybit_to_nautilus_trigger_type)
 
-    def parse_trigger_direction(  # noqa: C901 (too complex)
+    def parse_trigger_direction(
         self,
         order_type: OrderType,
         order_side: OrderSide,
     ) -> BybitTriggerDirection | None:
-        if order_side == OrderSide.BUY:
-            match order_type:
-                case OrderType.STOP_MARKET:
-                    return BybitTriggerDirection.RISES_TO
-                case OrderType.STOP_LIMIT:
-                    return BybitTriggerDirection.RISES_TO
-                case OrderType.MARKET_IF_TOUCHED:
-                    return BybitTriggerDirection.RISES_TO
-                case OrderType.TRAILING_STOP_MARKET:
-                    return BybitTriggerDirection.RISES_TO
-                case OrderType.LIMIT_IF_TOUCHED:
-                    return BybitTriggerDirection.FALLS_TO
-                case _:
-                    return None
-        else:  # SELL
-            match order_type:
-                case OrderType.STOP_MARKET:
-                    return BybitTriggerDirection.FALLS_TO
-                case OrderType.STOP_LIMIT:
-                    return BybitTriggerDirection.FALLS_TO
-                case OrderType.MARKET_IF_TOUCHED:
-                    return BybitTriggerDirection.FALLS_TO
-                case OrderType.TRAILING_STOP_MARKET:
-                    return BybitTriggerDirection.FALLS_TO
-                case OrderType.LIMIT_IF_TOUCHED:
-                    return BybitTriggerDirection.RISES_TO
-                case _:
-                    return None
+        return (
+            self.trigger_direction_map_buy.get(order_type)
+            if order_side == OrderSide.BUY
+            else self.trigger_direction_map_sell.get(order_type)
+        )
 
     def parse_bybit_kline(self, bar_type: BarType) -> BybitKlineInterval:
         try:
@@ -576,7 +587,7 @@ class BybitEnumParser:
                 raise ValueError(
                     f"Bybit incorrect aggregation {aggregation}",  # pragma: no cover
                 )
-        except KeyError:
+        except KeyError as e:
             raise RuntimeError(
                 f"unrecognized Bybit bar type, was {bar_type}",  # pragma: no cover
-            )
+            ) from e
