@@ -39,14 +39,15 @@ from nautilus_trader.adapters.bybit.http.client import BybitHttpClient
 from nautilus_trader.adapters.bybit.http.errors import BybitError
 from nautilus_trader.adapters.bybit.http.errors import should_retry
 from nautilus_trader.adapters.bybit.providers import BybitInstrumentProvider
-from nautilus_trader.adapters.bybit.schemas.common import BybitWsSubscriptionMsg
-from nautilus_trader.adapters.bybit.schemas.ws import BYBIT_PONG
+from nautilus_trader.adapters.bybit.schemas.common import BYBIT_PONG
 from nautilus_trader.adapters.bybit.schemas.ws import BybitWsAccountExecution
 from nautilus_trader.adapters.bybit.schemas.ws import BybitWsAccountExecutionMsg
 from nautilus_trader.adapters.bybit.schemas.ws import BybitWsAccountOrderMsg
 from nautilus_trader.adapters.bybit.schemas.ws import BybitWsAccountPositionMsg
+from nautilus_trader.adapters.bybit.schemas.ws import BybitWsAccountWalletMsg
 from nautilus_trader.adapters.bybit.schemas.ws import BybitWsMessageGeneral
-from nautilus_trader.adapters.bybit.websocket.client import BybitWebsocketClient
+from nautilus_trader.adapters.bybit.schemas.ws import BybitWsSubscriptionMsg
+from nautilus_trader.adapters.bybit.websocket.client import BybitWebSocketClient
 from nautilus_trader.cache.cache import Cache
 from nautilus_trader.common.component import LiveClock
 from nautilus_trader.common.component import MessageBus
@@ -171,7 +172,7 @@ class BybitExecutionClient(LiveExecutionClient):
         self._set_account_id(account_id)
 
         # WebSocket API
-        self._ws_client = BybitWebsocketClient(
+        self._ws_client = BybitWebSocketClient(
             clock=clock,
             handler=self._handle_ws_message,
             handler_reconnect=None,
@@ -180,6 +181,7 @@ class BybitExecutionClient(LiveExecutionClient):
             api_key=config.api_key or get_api_key(config.demo, config.testnet),
             api_secret=config.api_secret or get_api_secret(config.demo, config.testnet),
             loop=loop,
+            max_reconnection_tries=config.max_ws_reconnection_tries,
         )
 
         # HTTP API
@@ -202,13 +204,11 @@ class BybitExecutionClient(LiveExecutionClient):
         # Decoders
         self._decoder_ws_msg_general = msgspec.json.Decoder(BybitWsMessageGeneral)
         self._decoder_ws_subscription = msgspec.json.Decoder(BybitWsSubscriptionMsg)
+
         self._decoder_ws_account_order_update = msgspec.json.Decoder(BybitWsAccountOrderMsg)
-        self._decoder_ws_account_execution_update = msgspec.json.Decoder(
-            BybitWsAccountExecutionMsg,
-        )
-        self._decoder_ws_account_position_update = msgspec.json.Decoder(
-            BybitWsAccountPositionMsg,
-        )
+        self._decoder_ws_account_execution_update = msgspec.json.Decoder(BybitWsAccountExecutionMsg)
+        self._decoder_ws_account_position_update = msgspec.json.Decoder(BybitWsAccountPositionMsg)
+        self._decoder_ws_account_wallet_update = msgspec.json.Decoder(BybitWsAccountWalletMsg)
 
         # Hot caches
         self._instrument_ids: dict[str, InstrumentId] = {}
@@ -230,6 +230,7 @@ class BybitExecutionClient(LiveExecutionClient):
         await self._ws_client.connect()
         await self._ws_client.subscribe_executions_update()
         await self._ws_client.subscribe_orders_update()
+        await self._ws_client.subscribe_wallet_update()
 
     async def _disconnect(self) -> None:
         await self._ws_client.disconnect()
@@ -578,16 +579,15 @@ class BybitExecutionClient(LiveExecutionClient):
 
         for i in range(0, len(valid_cancels), max_batch):
             batch_cancels = valid_cancels[i : i + max_batch]
-            cancel_orders: list[BybitBatchCancelOrder] = []
 
-            for cancel in batch_cancels:
-                cancel_orders.append(
-                    BybitBatchCancelOrder(
-                        symbol=bybit_symbol.raw_symbol,
-                        orderId=cancel.venue_order_id.value if cancel.venue_order_id else None,
-                        orderLinkId=cancel.client_order_id.value,
-                    ),
+            cancel_orders: list[BybitBatchCancelOrder] = [
+                BybitBatchCancelOrder(
+                    symbol=bybit_symbol.raw_symbol,
+                    orderId=cancel.venue_order_id.value if cancel.venue_order_id else None,
+                    orderLinkId=cancel.client_order_id.value,
                 )
+                for cancel in batch_cancels
+            ]
 
             async with self._retry_manager_pool as retry_manager:
                 await retry_manager.run(
@@ -941,6 +941,8 @@ class BybitExecutionClient(LiveExecutionClient):
                 self._handle_account_order_update(raw)
             elif "execution" in ws_message.topic:
                 self._handle_account_execution_update(raw)
+            elif "wallet" == ws_message.topic:
+                self._handle_account_wallet_update(raw)
             else:
                 self._log.error(f"Unknown websocket message topic: {ws_message.topic}")
         except Exception as e:
@@ -958,7 +960,7 @@ class BybitExecutionClient(LiveExecutionClient):
         instrument_id = self._get_cached_instrument_id(execution.symbol, execution.category)
         client_order_id = ClientOrderId(execution.orderLinkId) if execution.orderLinkId else None
         venue_order_id = VenueOrderId(execution.orderId)
-        order_side = self._enum_parser.parse_bybit_order_side(execution.side)
+        order_side: OrderSide = self._enum_parser.parse_bybit_order_side(execution.side)
 
         if client_order_id is None:
             client_order_id = self._cache.client_order_id(venue_order_id)
@@ -984,7 +986,7 @@ class BybitExecutionClient(LiveExecutionClient):
             order_type = self._enum_parser.parse_bybit_order_type(
                 execution.orderType,
                 execution.stopOrderType,
-                order_side,
+                execution.side,
                 trigger_direction,
             )
         else:
@@ -1008,9 +1010,7 @@ class BybitExecutionClient(LiveExecutionClient):
             last_px=Price(float(execution.execPrice), instrument.price_precision),
             quote_currency=instrument.quote_currency,
             commission=Money(Decimal(execution.execFee), instrument.quote_currency),
-            liquidity_side=(
-                LiquiditySide.MAKER if order_type == OrderType.LIMIT else LiquiditySide.TAKER
-            ),
+            liquidity_side=LiquiditySide.MAKER if execution.isMaker else LiquiditySide.TAKER,
             ts_event=millis_to_nanos(float(execution.execTime)),
         )
 
@@ -1046,7 +1046,8 @@ class BybitExecutionClient(LiveExecutionClient):
                                 order,
                                 TrailingStopMarketOrder,
                             )
-                            or bybit_order.orderType == BybitOrderType.LIMIT
+                        ) or (
+                            bybit_order.orderType == BybitOrderType.LIMIT
                             and not isinstance(
                                 order,
                                 TrailingStopLimitOrder,
@@ -1159,6 +1160,16 @@ class BybitExecutionClient(LiveExecutionClient):
         except Exception as e:
             self._log.error(repr(e))
 
+    def _handle_account_wallet_update(self, raw: bytes) -> None:
+        try:
+            self._process_wallet_update(raw)
+        except Exception as e:
+            self._log.exception(f"Failed to handle account wallet update: {e}", e)
+
+    def _process_wallet_update(self, raw: bytes) -> None:
+        msg: BybitWsAccountWalletMsg = self._decoder_ws_account_wallet_update.decode(raw)
+        msg.handle_account_wallet_update(self)
+
     def _create_market_batch_order(
         self,
         order: MarketOrder,
