@@ -13,7 +13,7 @@
 #  limitations under the License.
 # -------------------------------------------------------------------------------------------------
 
-import msgspec as msgspec
+import msgspec
 
 from nautilus_trader.adapters.bybit.schemas.common import BybitListResult
 
