@@ -13,8 +13,10 @@
 #  limitations under the License.
 # -------------------------------------------------------------------------------------------------
 
+from __future__ import annotations
+
 from decimal import Decimal
-from typing import Final
+from typing import TYPE_CHECKING
 
 import msgspec
 
@@ -50,11 +52,16 @@ from nautilus_trader.model.identifiers import ClientOrderId
 from nautilus_trader.model.identifiers import InstrumentId
 from nautilus_trader.model.identifiers import TradeId
 from nautilus_trader.model.identifiers import VenueOrderId
+from nautilus_trader.model.objects import AccountBalance
+from nautilus_trader.model.objects import Currency
+from nautilus_trader.model.objects import MarginBalance
+from nautilus_trader.model.objects import Money
 from nautilus_trader.model.objects import Price
 from nautilus_trader.model.objects import Quantity
 
 
-BYBIT_PONG: Final[str] = "pong"
+if TYPE_CHECKING:
+    from nautilus_trader.adapters.bybit.execution import BybitExecutionClient
 
 
 class BybitWsMessageGeneral(msgspec.Struct):
@@ -64,6 +71,14 @@ class BybitWsMessageGeneral(msgspec.Struct):
     ret_msg: str | None = None
 
 
+class BybitWsSubscriptionMsg(msgspec.Struct):
+    success: bool
+    op: str
+    conn_id: str
+    ret_msg: str | None = None
+    req_id: str | None = None
+
+
 ################################################################################
 # Public - Kline
 ################################################################################
@@ -694,6 +709,25 @@ class BybitWsAccountWalletCoin(msgspec.Struct):
     collateralSwitch: bool
     marginCollateral: bool
     locked: str
+    spotHedgingQty: str
+
+    def parse_to_account_balance(self) -> AccountBalance:
+        currency = Currency.from_str(self.coin)
+        total = Decimal(self.walletBalance)
+        locked = Decimal(self.locked)  # TODO: Locked only valid for Spot
+        free = total - locked
+        return AccountBalance(
+            total=Money(total, currency),
+            locked=Money(locked, currency),
+            free=Money(free, currency),
+        )
+
+    def parse_to_margin_balance(self) -> MarginBalance:
+        currency: Currency = Currency.from_str(self.coin)
+        return MarginBalance(
+            initial=Money(Decimal(self.totalPositionIM), currency),
+            maintenance=Money(Decimal(self.totalPositionMM), currency),
+        )
 
 
 class BybitWsAccountWallet(msgspec.Struct):
@@ -710,9 +744,24 @@ class BybitWsAccountWallet(msgspec.Struct):
     accountLTV: str
     accountType: str
 
+    def parse_to_account_balance(self) -> list[AccountBalance]:
+        return [coin.parse_to_account_balance() for coin in self.coin]
+
+    def parse_to_margin_balance(self) -> list[MarginBalance]:
+        return [coin.parse_to_margin_balance() for coin in self.coin]
+
 
 class BybitWsAccountWalletMsg(msgspec.Struct):
     topic: str
     id: str
     creationTime: int
     data: list[BybitWsAccountWallet]
+
+    def handle_account_wallet_update(self, exec_client: BybitExecutionClient):
+        for wallet in self.data:
+            exec_client.generate_account_state(
+                balances=wallet.parse_to_account_balance(),
+                margins=wallet.parse_to_margin_balance(),
+                reported=True,
+                ts_event=millis_to_nanos(self.creationTime),
+            )
