@@ -356,7 +356,7 @@ class DatabentoDataClient(LiveMarketDataClient):
         instrument_id: InstrumentId,
         book_type: BookType,
         depth: int | None = None,
-        kwargs: dict[str, Any] | None = None,
+        params: dict[str, Any] | None = None,
     ) -> None:
         if book_type != BookType.L3_MBO:
             raise NotImplementedError
@@ -366,7 +366,7 @@ class DatabentoDataClient(LiveMarketDataClient):
                 instrument_id=instrument_id,
                 book_type=book_type,
                 depth=depth,
-                kwargs=kwargs,
+                params=params,
             ),
             log_msg=f"subscribe: order_book_deltas {instrument_id}",
             actions=lambda: self._add_subscription_order_book_deltas(instrument_id),
@@ -374,7 +374,7 @@ class DatabentoDataClient(LiveMarketDataClient):
 
     # -- SUBSCRIPTIONS ----------------------------------------------------------------------------
 
-    async def _subscribe(self, data_type: DataType) -> None:
+    async def _subscribe(self, data_type: DataType, params: dict[str, Any] | None = None) -> None:
         if data_type.type == DatabentoImbalance:
             await self._subscribe_imbalance(data_type)
         elif data_type.type == DatabentoStatistics:
@@ -412,11 +412,15 @@ class DatabentoDataClient(LiveMarketDataClient):
         except asyncio.CancelledError:
             self._log.warning("`_subscribe_imbalance` was canceled while still pending")
 
-    async def _subscribe_instruments(self) -> None:
+    async def _subscribe_instruments(self, params: dict[str, Any] | None = None) -> None:
         # Replace method in child class, for exchange specific data types.
         raise NotImplementedError("Cannot subscribe to all instruments (not currently supported).")
 
-    async def _subscribe_instrument(self, instrument_id: InstrumentId) -> None:
+    async def _subscribe_instrument(
+        self,
+        instrument_id: InstrumentId,
+        params: dict[str, Any] | None = None,
+    ) -> None:
         try:
             dataset: Dataset = self._loader.get_dataset_for_venue(instrument_id.venue)
             live_client = self._get_live_client(dataset)
@@ -464,7 +468,7 @@ class DatabentoDataClient(LiveMarketDataClient):
         instrument_id: InstrumentId,
         book_type: BookType,
         depth: int | None = None,
-        kwargs: dict | None = None,
+        params: dict[str, Any] | None = None,
     ) -> None:
         try:
             if book_type != BookType.L3_MBO:
@@ -555,7 +559,7 @@ class DatabentoDataClient(LiveMarketDataClient):
         instrument_id: InstrumentId,
         book_type: BookType,
         depth: int | None = None,
-        kwargs: dict | None = None,
+        params: dict[str, Any] | None = None,
     ) -> None:
         try:
             await self._ensure_subscribed_for_instrument(instrument_id)
@@ -581,14 +585,27 @@ class DatabentoDataClient(LiveMarketDataClient):
         except asyncio.CancelledError:
             self._log.warning("`_subscribe_order_book_snapshots` was canceled while still pending")
 
-    async def _subscribe_quote_ticks(self, instrument_id: InstrumentId) -> None:
+    async def _subscribe_quote_ticks(
+        self,
+        instrument_id: InstrumentId,
+        params: dict[str, Any] | None = None,
+    ) -> None:
         try:
             await self._ensure_subscribed_for_instrument(instrument_id)
 
+            schema: str | None = params.get("schema") if params else None
+            # allowed schema values: mbp-1, bbo-1s, bbo-1m
+            if schema is None or schema not in [
+                DatabentoSchema.MBP_1.value,
+                DatabentoSchema.BBO_1S.value,
+                DatabentoSchema.BBO_1M.value,
+            ]:
+                schema = DatabentoSchema.MBP_1.value
+
             dataset: Dataset = self._loader.get_dataset_for_venue(instrument_id.venue)
             live_client = self._get_live_client(dataset)
             live_client.subscribe(
-                schema=DatabentoSchema.MBP_1.value,
+                schema=schema,
                 symbols=[instrument_id.symbol.value],
             )
 
@@ -599,7 +616,11 @@ class DatabentoDataClient(LiveMarketDataClient):
         except asyncio.CancelledError:
             self._log.warning("`_subscribe_quote_ticks` was canceled while still pending")
 
-    async def _subscribe_trade_ticks(self, instrument_id: InstrumentId) -> None:
+    async def _subscribe_trade_ticks(
+        self,
+        instrument_id: InstrumentId,
+        params: dict[str, Any] | None = None,
+    ) -> None:
         try:
             if instrument_id in self._trade_tick_subscriptions:
                 return  # Already subscribed (this will save on data costs)
@@ -616,7 +637,11 @@ class DatabentoDataClient(LiveMarketDataClient):
         except asyncio.CancelledError:
             self._log.warning("`_subscribe_trade_ticks` was canceled while still pending")
 
-    async def _subscribe_bars(self, bar_type: BarType) -> None:
+    async def _subscribe_bars(
+        self,
+        bar_type: BarType,
+        params: dict[str, Any] | None = None,
+    ) -> None:
         try:
             dataset: Dataset = self._loader.get_dataset_for_venue(bar_type.instrument_id.venue)
 
@@ -635,7 +660,11 @@ class DatabentoDataClient(LiveMarketDataClient):
         except asyncio.CancelledError:
             self._log.warning("`_subscribe_bars` was canceled while still pending")
 
-    async def _subscribe_instrument_status(self, instrument_id: InstrumentId) -> None:
+    async def _subscribe_instrument_status(
+        self,
+        instrument_id: InstrumentId,
+        params: dict[str, Any] | None = None,
+    ) -> None:
         try:
             dataset: Dataset = self._loader.get_dataset_for_venue(instrument_id.venue)
 
@@ -648,59 +677,92 @@ class DatabentoDataClient(LiveMarketDataClient):
         except asyncio.CancelledError:
             self._log.warning("`_subscribe_bars` was canceled while still pending")
 
-    async def _unsubscribe(self, data_type: DataType) -> None:
+    async def _unsubscribe(self, data_type: DataType, params: dict[str, Any] | None = None) -> None:
         raise NotImplementedError(
             f"Cannot unsubscribe from {data_type}, unsubscribing not supported by Databento.",
         )
 
-    async def _unsubscribe_instruments(self) -> None:
+    async def _unsubscribe_instruments(self, params: dict[str, Any] | None = None) -> None:
         raise NotImplementedError(
             "Cannot unsubscribe from all instruments, unsubscribing not supported by Databento.",
         )
 
-    async def _unsubscribe_instrument(self, instrument_id: InstrumentId) -> None:
+    async def _unsubscribe_instrument(
+        self,
+        instrument_id: InstrumentId,
+        params: dict[str, Any] | None = None,
+    ) -> None:
         raise NotImplementedError(
             f"Cannot unsubscribe from {instrument_id} instrument, "
             "unsubscribing not supported by Databento.",
         )
 
-    async def _unsubscribe_order_book_deltas(self, instrument_id: InstrumentId) -> None:
+    async def _unsubscribe_order_book_deltas(
+        self,
+        instrument_id: InstrumentId,
+        params: dict[str, Any] | None = None,
+    ) -> None:
         raise NotImplementedError(
             f"Cannot unsubscribe from {instrument_id} order book deltas, "
             "unsubscribing not supported by Databento.",
         )
 
-    async def _unsubscribe_order_book_snapshots(self, instrument_id: InstrumentId) -> None:
+    async def _unsubscribe_order_book_snapshots(
+        self,
+        instrument_id: InstrumentId,
+        params: dict[str, Any] | None = None,
+    ) -> None:
         raise NotImplementedError(
             f"Cannot unsubscribe from {instrument_id} order book snapshots, "
             "unsubscribing not supported by Databento.",
         )
 
-    async def _unsubscribe_quote_ticks(self, instrument_id: InstrumentId) -> None:
+    async def _unsubscribe_quote_ticks(
+        self,
+        instrument_id: InstrumentId,
+        params: dict[str, Any] | None = None,
+    ) -> None:
         raise NotImplementedError(
             f"Cannot unsubscribe from {instrument_id} quotes, "
             "unsubscribing not supported by Databento.",
         )
 
-    async def _unsubscribe_trade_ticks(self, instrument_id: InstrumentId) -> None:
+    async def _unsubscribe_trade_ticks(
+        self,
+        instrument_id: InstrumentId,
+        params: dict[str, Any] | None = None,
+    ) -> None:
         raise NotImplementedError(
             f"Cannot unsubscribe from {instrument_id} trades, "
             "unsubscribing not supported by Databento.",
         )
 
-    async def _unsubscribe_bars(self, bar_type: BarType) -> None:
+    async def _unsubscribe_bars(
+        self,
+        bar_type: BarType,
+        params: dict[str, Any] | None = None,
+    ) -> None:
         raise NotImplementedError(
             f"Cannot unsubscribe from {bar_type} bars, "
             "unsubscribing not supported by Databento.",
         )
 
-    async def _unsubscribe_instrument_status(self, instrument_id: InstrumentId) -> None:
+    async def _unsubscribe_instrument_status(
+        self,
+        instrument_id: InstrumentId,
+        params: dict[str, Any] | None = None,
+    ) -> None:
         raise NotImplementedError(
             f"Cannot unsubscribe from {instrument_id} instrument status, "
             "unsubscribing not supported by Databento.",
         )
 
-    async def _request(self, data_type: DataType, correlation_id: UUID4) -> None:
+    async def _request(
+        self,
+        data_type: DataType,
+        correlation_id: UUID4,
+        params: dict[str, Any] | None = None,
+    ) -> None:
         if data_type.type == InstrumentStatus:
             await self._request_instrument_status(data_type, correlation_id)
         elif data_type.type == DatabentoImbalance:
@@ -713,7 +775,11 @@ class DatabentoDataClient(LiveMarketDataClient):
                 f"Cannot request {data_type.type} (not implemented)",
             )
 
-    async def _request_instrument_status(self, data_type: DataType, correlation_id: UUID4) -> None:
+    async def _request_instrument_status(
+        self,
+        data_type: DataType,
+        correlation_id: UUID4,
+    ) -> None:
         instrument_id: InstrumentId = data_type.metadata["instrument_id"]
         start = data_type.metadata.get("start")
         end = data_type.metadata.get("end")
@@ -743,6 +809,7 @@ class DatabentoDataClient(LiveMarketDataClient):
             data_type=data_type,
             data=status,
             correlation_id=correlation_id,
+            params=None,
         )
 
     async def _request_imbalance(self, data_type: DataType, correlation_id: UUID4) -> None:
@@ -773,6 +840,7 @@ class DatabentoDataClient(LiveMarketDataClient):
             data_type=data_type,
             data=pyo3_imbalances,
             correlation_id=correlation_id,
+            params=None,
         )
 
     async def _request_statistics(self, data_type: DataType, correlation_id: UUID4) -> None:
@@ -803,6 +871,7 @@ class DatabentoDataClient(LiveMarketDataClient):
             data_type=data_type,
             data=pyo3_statistics,
             correlation_id=correlation_id,
+            params=None,
         )
 
     async def _request_instrument(
@@ -811,6 +880,7 @@ class DatabentoDataClient(LiveMarketDataClient):
         correlation_id: UUID4,
         start: pd.Timestamp | None = None,
         end: pd.Timestamp | None = None,
+        params: dict[str, Any] | None = None,
     ) -> None:
         dataset: Dataset = self._loader.get_dataset_for_venue(instrument_id.venue)
         _, available_end = await self._get_dataset_range(dataset)
@@ -839,10 +909,7 @@ class DatabentoDataClient(LiveMarketDataClient):
             )
             return
 
-        self._handle_instrument(
-            instrument=instruments[0],
-            correlation_id=correlation_id,
-        )
+        self._handle_instrument(instruments[0], correlation_id, params)
 
     async def _request_instruments(
         self,
@@ -850,6 +917,7 @@ class DatabentoDataClient(LiveMarketDataClient):
         correlation_id: UUID4,
         start: pd.Timestamp | None = None,
         end: pd.Timestamp | None = None,
+        params: dict[str, Any] | None = None,
     ) -> None:
         dataset: Dataset = self._loader.get_dataset_for_venue(venue)
         _, available_end = await self._get_dataset_range(dataset)
@@ -872,11 +940,7 @@ class DatabentoDataClient(LiveMarketDataClient):
 
         instruments = instruments_from_pyo3(pyo3_instruments)
 
-        self._handle_instruments(
-            instruments=instruments,
-            venue=venue,
-            correlation_id=correlation_id,
-        )
+        self._handle_instruments(instruments, venue, correlation_id, params)
 
     async def _request_quote_ticks(
         self,
@@ -885,6 +949,7 @@ class DatabentoDataClient(LiveMarketDataClient):
         correlation_id: UUID4,
         start: pd.Timestamp | None = None,
         end: pd.Timestamp | None = None,
+        params: dict[str, Any] | None = None,
     ) -> None:
         dataset: Dataset = self._loader.get_dataset_for_venue(instrument_id.venue)
         _, available_end = await self._get_dataset_range(dataset)
@@ -902,20 +967,26 @@ class DatabentoDataClient(LiveMarketDataClient):
             LogColor.BLUE,
         )
 
+        schema: str | None = params.get("schema") if params else None
+        # allowed schema values: mbp-1, bbo-1s, bbo-1m
+        if schema is None or schema not in [
+            DatabentoSchema.MBP_1.value,
+            DatabentoSchema.BBO_1S.value,
+            DatabentoSchema.BBO_1M.value,
+        ]:
+            schema = DatabentoSchema.MBP_1.value
+
         pyo3_quotes = await self._http_client.get_range_quotes(
             dataset=dataset,
             symbols=[instrument_id.symbol.value],
             start=start.value,
             end=end.value,
+            schema=schema,
         )
 
         quotes = QuoteTick.from_pyo3_list(pyo3_quotes)
 
-        self._handle_quote_ticks(
-            instrument_id=instrument_id,
-            ticks=quotes,
-            correlation_id=correlation_id,
-        )
+        self._handle_quote_ticks(instrument_id, quotes, correlation_id, params)
 
     async def _request_trade_ticks(
         self,
@@ -924,6 +995,7 @@ class DatabentoDataClient(LiveMarketDataClient):
         correlation_id: UUID4,
         start: pd.Timestamp | None = None,
         end: pd.Timestamp | None = None,
+        params: dict[str, Any] | None = None,
     ) -> None:
         dataset: Dataset = self._loader.get_dataset_for_venue(instrument_id.venue)
         _, available_end = await self._get_dataset_range(dataset)
@@ -950,11 +1022,7 @@ class DatabentoDataClient(LiveMarketDataClient):
 
         trades = TradeTick.from_pyo3_list(pyo3_trades)
 
-        self._handle_trade_ticks(
-            instrument_id=instrument_id,
-            ticks=trades,
-            correlation_id=correlation_id,
-        )
+        self._handle_trade_ticks(instrument_id, trades, correlation_id, params)
 
     async def _request_bars(
         self,
@@ -963,6 +1031,7 @@ class DatabentoDataClient(LiveMarketDataClient):
         correlation_id: UUID4,
         start: pd.Timestamp | None = None,
         end: pd.Timestamp | None = None,
+        params: dict[str, Any] | None = None,
     ) -> None:
         dataset: Dataset = self._loader.get_dataset_for_venue(bar_type.instrument_id.venue)
         _, available_end = await self._get_dataset_range(dataset)
@@ -998,6 +1067,7 @@ class DatabentoDataClient(LiveMarketDataClient):
             bars=bars,
             partial=None,  # No partials
             correlation_id=correlation_id,
+            params=params,
         )
 
     def _handle_msg_pyo3(
