@@ -14,6 +14,7 @@
 # -------------------------------------------------------------------------------------------------
 
 from nautilus_trader.config import NautilusConfig
+from nautilus_trader.model.objects import Price
 
 
 class DYDXOrderTags(NautilusConfig, frozen=True, repr_omit_defaults=True):
@@ -23,6 +24,7 @@ class DYDXOrderTags(NautilusConfig, frozen=True, repr_omit_defaults=True):
 
     is_short_term_order: bool = True
     num_blocks_open: int = 20
+    market_order_price: Price | None = None
 
     @property
     def value(self) -> str:
