@@ -52,6 +52,9 @@ class DYDXWebsocketClient:
         The event loop for the client.
     subscription_rate_limit_per_second : int, default 2
         The maximum number of subscription message to send to the venue.
+    max_reconnection_tries: int, default 3
+        The number of retries to reconnect the websocket connection if the
+        connection is broken.
 
     """
 
@@ -63,6 +66,7 @@ class DYDXWebsocketClient:
         handler_reconnect: Callable[..., Awaitable[None]] | None,
         loop: asyncio.AbstractEventLoop,
         subscription_rate_limit_per_second: int = 2,
+        max_reconnection_tries: int | None = 3,
     ) -> None:
         """
         Provide a dYdX streaming WebSocket client.
@@ -77,6 +81,7 @@ class DYDXWebsocketClient:
         self._is_running = False
         self._subscriptions: set[tuple[str, str]] = set()
         self._subscription_rate_limit_per_second = subscription_rate_limit_per_second
+        self._max_reconnection_tries = max_reconnection_tries
         self._msg_timestamp = self._clock.utc_now()
         self._msg_timeout_secs: int = 60
         self._reconnect_task: asyncio.Task | None = None
@@ -145,6 +150,7 @@ class DYDXWebsocketClient:
             heartbeat=10,
             headers=[],
             ping_handler=self._handle_ping,
+            max_reconnection_tries=self._max_reconnection_tries,
         )
         client = await WebSocketClient.connect(
             config=config,
@@ -317,7 +323,7 @@ class DYDXWebsocketClient:
             return
 
         self._subscriptions.add(subscription)
-        msg = {"type": "subscribe", "channel": "v4_orderbook", "id": symbol, "batched": True}
+        msg = {"type": "subscribe", "channel": "v4_orderbook", "id": symbol}
         self._log.debug(f"Subscribe to {symbol} order book")
         await self._send(msg)
 
@@ -393,6 +399,24 @@ class DYDXWebsocketClient:
         msg = {"type": "subscribe", "channel": channel, "id": channel_id}
         await self._send(msg)
 
+    async def subscribe_block_height(self) -> None:
+        """
+        Subscribe to block height messages.
+        """
+        if self._client is None:
+            self._log.warning("Cannot subscribe to trades: not connected")
+            return
+
+        subscription = ("v4_block_height", "")
+        if subscription in self._subscriptions:
+            self._log.warning(f"Cannot subscribe '{subscription}': already subscribed")
+            return
+
+        self._subscriptions.add(subscription)
+        msg = {"type": "subscribe", "channel": "v4_block_height"}
+        self._log.debug("Subscribe to block height updates")
+        await self._send(msg)
+
     async def unsubscribe_account_update(self, wallet_address: str, subaccount_number: int) -> None:
         """
         Unsubscribe from account updates.
@@ -514,6 +538,25 @@ class DYDXWebsocketClient:
         msg = {"type": "unsubscribe", "channel": "v4_markets"}
         await self._send(msg)
 
+    async def unsubscribe_block_height(self) -> None:
+        """
+        Unsubscribe from block height updates.
+        """
+        if self._client is None:
+            self._log.warning("Cannot unsubscribe: not connected")
+            return
+
+        channel = "v4_block_height"
+
+        subscription = (channel, "")
+        if subscription not in self._subscriptions:
+            self._log.warning(f"Cannot unsubscribe '{subscription}': not subscribed")
+            return
+
+        self._subscriptions.remove(subscription)
+        msg = {"type": "unsubscribe", "channel": channel}
+        await self._send(msg)
+
     async def _subscribe_all(self) -> None:
         """
         Resubscribe to all previous subscriptions.
@@ -526,11 +569,10 @@ class DYDXWebsocketClient:
             msg: dict[str, Any] = {
                 "type": "subscribe",
                 "channel": subscription[0],
-                "id": subscription[1],
             }
 
-            if subscription[0] == "v4_orderbook":
-                msg["batched"] = True
+            if subscription[0] not in ("v4_block_height", "v4_markets"):
+                msg["id"] = subscription[1]
 
             await self._send(msg)
 
