@@ -478,6 +478,7 @@ class InteractiveBrokersClient(
         request: Request,
         timeout: int,
         default_value: Any | None = None,
+        supress_timeout_warning: bool = False,
     ) -> Any:
         """
         Await the completion of a request within a specified timeout.
@@ -490,6 +491,8 @@ class InteractiveBrokersClient(
             The maximum time to wait for the request to complete, in seconds.
         default_value : Any, optional
             The default value to return if the request times out or fails. Defaults to None.
+        supress_timeout_warning: bool, optional
+            Suppress the timeout warning. Defaults to False.
 
         Returns
         -------
@@ -500,7 +503,8 @@ class InteractiveBrokersClient(
         try:
             return await asyncio.wait_for(request.future, timeout)
         except TimeoutError as e:
-            self._log.warning(f"Request timed out for {request}. Ending request.")
+            msg = f"Request timed out for {request}. Ending request."
+            self._log.debug(msg) if supress_timeout_warning else self._log.warning(msg)
             self._end_request(request.req_id, success=False, exception=e)
             return default_value
         except ConnectionError as e:
@@ -581,10 +585,8 @@ class InteractiveBrokersClient(
         )
         try:
             while (
-                self._eclient.conn
-                and self._eclient.conn.isConnected()
-                or not self._internal_msg_queue.empty()
-            ):
+                self._eclient.conn and self._eclient.conn.isConnected()
+            ) or not self._internal_msg_queue.empty():
                 msg = await self._internal_msg_queue.get()
                 if not await self._process_message(msg):
                     break
