@@ -16,11 +16,13 @@
 from typing import Final
 
 from nautilus_trader.adapters.polymarket.schemas.book import PolymarketBookSnapshot
-from nautilus_trader.adapters.polymarket.schemas.book import PolymarketQuote
+from nautilus_trader.adapters.polymarket.schemas.book import PolymarketQuotes
 from nautilus_trader.adapters.polymarket.schemas.book import PolymarketTrade
 from nautilus_trader.adapters.polymarket.schemas.user import PolymarketUserOrder
 from nautilus_trader.adapters.polymarket.schemas.user import PolymarketUserTrade
 
 
-MARKET_WS_MESSAGE: Final = PolymarketBookSnapshot | PolymarketQuote | PolymarketTrade
-USER_WS_MESSAGE: Final = PolymarketUserOrder | PolymarketUserTrade
+MARKET_WS_MESSAGE: Final = list[
+    list[PolymarketBookSnapshot] | PolymarketBookSnapshot | PolymarketQuotes | PolymarketTrade
+]
+USER_WS_MESSAGE: Final = list[PolymarketUserOrder | PolymarketUserTrade]
