@@ -17,10 +17,10 @@ from dataclasses import field
 
 import numpy as np
 
-from nautilus_trader.common.math import quadratic_interpolation
 from nautilus_trader.core.data import Data
 from nautilus_trader.core.datetime import unix_nanos_to_dt
 from nautilus_trader.core.datetime import unix_nanos_to_str
+from nautilus_trader.core.math import quadratic_interpolation
 from nautilus_trader.model.custom import customdataclass
 from nautilus_trader.model.identifiers import InstrumentId
 
@@ -183,11 +183,12 @@ class InterestRateCurveData(Data):
 
         return result
 
-    def from_dict(self, data):
+    @classmethod
+    def from_dict(cls, data):
         data.pop("type", None)
         data.pop("date", None)
 
         data["tenors"] = np.frombuffer(data["tenors"])
-        data["interst_rates"] = np.frombuffer(data["interest_rates"])
+        data["interest_rates"] = np.frombuffer(data["interest_rates"])
 
         return InterestRateCurveData(**data)
