@@ -61,7 +61,7 @@ SCHEMAS = {
         },
         metadata={"type": "BettingInstrument"},
     ),
-    BinaryOption: pa.schema(  # TBD
+    BinaryOption: pa.schema(
         {
             "id": pa.dictionary(pa.int64(), pa.string()),
             "raw_symbol": pa.string(),
@@ -230,6 +230,10 @@ SCHEMAS = {
             "lot_size": pa.dictionary(pa.int16(), pa.string()),
             "activation_ns": pa.uint64(),
             "expiration_ns": pa.uint64(),
+            "margin_init": pa.string(),
+            "margin_maint": pa.string(),
+            "maker_fee": pa.string(),
+            "taker_fee": pa.string(),
             "info": pa.binary(),
             "ts_event": pa.uint64(),
             "ts_init": pa.uint64(),
@@ -252,6 +256,10 @@ SCHEMAS = {
             "lot_size": pa.dictionary(pa.int16(), pa.string()),
             "activation_ns": pa.uint64(),
             "expiration_ns": pa.uint64(),
+            "margin_init": pa.string(),
+            "margin_maint": pa.string(),
+            "maker_fee": pa.string(),
+            "taker_fee": pa.string(),
             "info": pa.binary(),
             "ts_event": pa.uint64(),
             "ts_init": pa.uint64(),
@@ -275,6 +283,10 @@ SCHEMAS = {
             "size_increment": pa.dictionary(pa.int16(), pa.string()),
             "multiplier": pa.dictionary(pa.int16(), pa.string()),
             "lot_size": pa.dictionary(pa.int16(), pa.string()),
+            "margin_init": pa.string(),
+            "margin_maint": pa.string(),
+            "maker_fee": pa.string(),
+            "taker_fee": pa.string(),
             "info": pa.binary(),
             "ts_event": pa.uint64(),
             "ts_init": pa.uint64(),
@@ -297,6 +309,10 @@ SCHEMAS = {
             "lot_size": pa.dictionary(pa.int16(), pa.string()),
             "activation_ns": pa.uint64(),
             "expiration_ns": pa.uint64(),
+            "margin_init": pa.string(),
+            "margin_maint": pa.string(),
+            "maker_fee": pa.string(),
+            "taker_fee": pa.string(),
             "info": pa.binary(),
             "ts_event": pa.uint64(),
             "ts_init": pa.uint64(),
@@ -350,12 +366,16 @@ def deserialize(batch: pa.RecordBatch) -> list[Instrument]:
         b"BettingInstrument": BettingInstrument,
         b"BinaryOption": BinaryOption,
         b"Cfd": Cfd,
+        b"Commodity": Commodity,
         b"CurrencyPair": CurrencyPair,
         b"CryptoPerpetual": CryptoPerpetual,
         b"CryptoFuture": CryptoFuture,
         b"Equity": Equity,
         b"FuturesContract": FuturesContract,
+        b"FuturesSpread": FuturesSpread,
+        b"IndexInstrument": IndexInstrument,
         b"OptionsContract": OptionsContract,
+        b"OptionsSpread": OptionsSpread,
     }[ins_type]
 
     maps = batch.to_pylist()
