@@ -15,6 +15,7 @@
 
 import asyncio
 import concurrent.futures
+import os
 import platform
 import signal
 import socket
@@ -47,6 +48,7 @@ from nautilus_trader.common.config import msgspec_encoding_hook
 from nautilus_trader.common.enums import LogColor
 from nautilus_trader.common.enums import LogLevel
 from nautilus_trader.common.enums import log_level_from_str
+from nautilus_trader.common.messages import ShutdownSystem
 from nautilus_trader.config import ActorFactory
 from nautilus_trader.config import ControllerFactory
 from nautilus_trader.config import DataEngineConfig
@@ -170,6 +172,9 @@ class NautilusKernel:
         logging: LoggingConfig = config.logging or LoggingConfig()
 
         if not is_logging_initialized():
+            if "RUST_LOG" not in os.environ:
+                os.environ["RUST_LOG"] = "off"
+
             if not logging.bypass_logging:
                 if logging.clear_log_file and logging.log_directory and logging.log_file_name:
                     file_path = Path(
@@ -184,6 +189,7 @@ class NautilusKernel:
 
                 if logging.use_pyo3:
                     set_logging_pyo3(True)
+
                     # Initialize tracing for async Rust
                     nautilus_pyo3.init_tracing()
 
@@ -317,6 +323,8 @@ class NautilusKernel:
             config=config.message_bus,
         )
 
+        self._setup_shutdown_handling()
+
         self._cache = Cache(
             database=cache_db,
             config=config.cache,
@@ -469,16 +477,24 @@ class NautilusKernel:
             self._setup_streaming(config=config.streaming)
 
         # Set up data catalog
-        self._catalogs: list[ParquetDataCatalog] = []
+        self._catalogs: dict[str, ParquetDataCatalog] = {}
         if config.catalogs:
+            catalog_name_index = 0
             for catalog_config in config.catalogs:
                 catalog = ParquetDataCatalog(
                     path=catalog_config.path,
                     fs_protocol=catalog_config.fs_protocol,
                     fs_storage_options=catalog_config.fs_storage_options,
                 )
-                self._catalogs.append(catalog)
-                self._data_engine.register_catalog(catalog=catalog)
+
+                used_catalog_name = catalog_config.name
+
+                if used_catalog_name is None:
+                    used_catalog_name = f"catalog_{catalog_name_index}"
+                    catalog_name_index += 1
+
+                self._catalogs[used_catalog_name] = catalog
+                self._data_engine.register_catalog(catalog, used_catalog_name)
 
         # Create importable actors
         for actor_config in config.actors:
@@ -525,6 +541,9 @@ class NautilusKernel:
         if self._loop_sig_callback:
             self._loop_sig_callback(sig)
 
+    def _setup_shutdown_handling(self) -> None:
+        self._msgbus.subscribe("commands.system.shutdown", self._on_shutdown_system)
+
     def _setup_streaming(self, config: StreamingConfig) -> None:
         # Set up persistence
         path = f"{config.catalog_path}/{self._environment.value}/{self.instance_id}"
@@ -549,6 +568,18 @@ class NautilusKernel:
         with self._writer.fs.open(full_path, "wb") as f:
             f.write(self._config.json())
 
+    def _on_shutdown_system(self, command: ShutdownSystem):
+        if command.trader_id != self.trader_id:
+            self._log.warning(f"Received {command!r} not for this trader {self.trader_id}")
+            return
+
+        self._log.info(f"Received {command!r}, shutting down...", LogColor.BLUE)
+
+        if self._loop:
+            self._loop.create_task(self.stop_async())
+        else:
+            self.stop()
+
     @property
     def environment(self) -> Environment:
         """
@@ -838,13 +869,13 @@ class NautilusKernel:
         return self._writer
 
     @property
-    def catalogs(self) -> list[ParquetDataCatalog]:
+    def catalogs(self) -> dict[str, ParquetDataCatalog]:
         """
         Return the kernel's list of data catalogs.
 
         Returns
         -------
-        list[ParquetDataCatalog]
+        dict[str, ParquetDataCatalog]
 
         """
         return self._catalogs
@@ -913,7 +944,7 @@ class NautilusKernel:
         if self._controller:
             self._controller.start()
 
-    async def stop(self) -> None:
+    def stop(self) -> None:
         """
         Stop the Nautilus system kernel.
         """
@@ -957,8 +988,6 @@ class NautilusKernel:
 
         self._log.info("STOPPING")
 
-        self._stop_clients()
-
         if self._trader.is_running:
             self._trader.stop()
             await self._await_trader_residuals()
@@ -966,6 +995,7 @@ class NautilusKernel:
         if self.save_state:
             self._trader.save()
 
+        self._stop_clients()
         self._disconnect_clients()
 
         await self._await_engines_disconnected()
